//====================================================================
// NAME: cd_apb.v
// DESC: cordic APB interface
// HISTORY
// 11/22/2005: 
//	- first draft
//====================================================================


module Cd_APB_if(
	PCLK,
	PRESETn,
	PSEL,
	PADDR,
        PENABLE,
	PWRITE,
	PWDATA,
	PRDATA,
	INT,
	reg_ctrl,
	reg_x_in,
	reg_y_in,
	reg_z_in,
	reg_x_out,
	reg_y_out,
	reg_z_out,
	reg_status
);	

input PCLK;
input PRESETn;
input PSEL;
input [4:0] PADDR;
input PENABLE;
input PWRITE;
input [31:0] PWDATA;
output [31:0] PRDATA;

output INT;

output [31:0] reg_ctrl;
output [31:0] reg_x_in;
output [31:0] reg_y_in;
output [31:0] reg_z_in;

input [31:0] reg_x_out;
input [31:0] reg_y_out;
input [31:0] reg_z_out;
input [31:0] reg_status;


reg [31:0] reg_ctrl;
reg [31:0] reg_x_in;
reg [31:0] reg_y_in;
reg [31:0] reg_z_in;


reg [1:0] apb_state;



// APB I/F states
`define APB_ST0		2'd0	//wait
`define APB_ST_W	2'd1	//write	
`define APB_ST_R	2'd2	//read



// APB I/F FSM

always @(posedge PCLK)
begin
    if(!PRESETn)begin
	apb_state<= `APB_ST0;
    end
    else begin
    	case(apb_state)
	`APB_ST0:begin
	    if(PSEL) begin
		if(PWRITE)
		    apb_state<=`APB_ST_W;
		else
		    apb_state<=`APB_ST_R;
		end
	    else
		apb_state<=`APB_ST0;
	  end
	`APB_ST_W:begin
	    apb_state<=`APB_ST0;
	  end
	`APB_ST_R:begin
	    apb_state<=`APB_ST0;
	  end
	default:begin
	    apb_state<=`APB_ST0;
	  end
	endcase
    end
end				 




// cordic address map
// 0x0 : reg_ctrl;
// 0x4 : reg_x_in;
// 0x8 : reg_y_in;
// 0xc : reg_z_in;
// 0x10: reg_x_out;
// 0x14: reg_y_out;
// 0x18: reg_z_out;
// 0x1c: reg_status;
// reg_ctrl


wire reg_ctrl_inten = reg_ctrl[5];
wire reg_ctrl_start = reg_ctrl[0];


always @(posedge PCLK)
begin
    if(!PRESETn)begin
	reg_ctrl<=32'b0;
	reg_x_in<=32'b0;
	reg_y_in<=32'b0;
	reg_z_in<=32'b0;
    end
    else begin
	if(!reg_ctrl_start)begin
	    if(PSEL && PENABLE )begin
	        case(PADDR)
	        5'h0:
		    reg_ctrl<=PWDATA;
	        5'h4:
		    reg_x_in<=PWDATA;
	        5'h8:
		    reg_y_in<=PWDATA;
	        5'hc:
		    reg_z_in<=PWDATA;
	        endcase
	    end 
	end
	else begin
	    reg_ctrl<=reg_ctrl & ~(32'b1000001); 
		//clear start bit and clear_pending_int bit automatically
	end
    end
end



assign PRDATA = ( apb_state==`APB_ST_R && PADDR==5'h00)? reg_ctrl   :
		( apb_state==`APB_ST_R && PADDR==5'h04)? reg_x_in   :
		( apb_state==`APB_ST_R && PADDR==5'h08)? reg_y_in   :
		( apb_state==`APB_ST_R && PADDR==5'h0c)? reg_z_in:
		( apb_state==`APB_ST_R && PADDR==5'h10)? reg_x_out  :
		( apb_state==`APB_ST_R && PADDR==5'h14)? reg_y_out  :
		( apb_state==`APB_ST_R && PADDR==5'h18)? reg_z_out :
		( apb_state==`APB_ST_R && PADDR==5'h1c)? reg_status : 32'b0;


	
assign INT = reg_status[0] & reg_ctrl_inten;


endmodule


