//====================================================================
// NAME: cd_atan.v
// DESC: module for calculating atan(). 
//       hybrid module for on-line cordic and sequential cordic.
//
// HISTORY
// 12/02/2005: 
//	- first draft
//====================================================================




module Cd_atan(	PCLK,
		PRESETn,
		xs0,
		ys0,
		zs0,
		i,
		start,
		xs_out,	//for debug only
		xc_out,	//for debug only
		zs_out,
		zc_out  
);

//bit 31 30 29 28 27 26 ...
//i=   x  x  0  1  2  3 ...

input PCLK,PRESETn;
input [31:0] xs0,ys0,zs0;
input [4:0] i;
input start;
output [31:0] xs_out,xc_out,zs_out,zc_out;
wire [31:0] ys_out,yc_out;

reg [31:0] xs,xc,ys,yc,zs,zc;


wire [31:0] xs_s1,xc_s1,ys_s1,yc_s1,zs_s1,zc_s1;
//wire [31:0] e_i0,e_i1;
wire [4:0]  i1;


reg atan_state;

`define ATAN_IDLE	1'b0
`define ATAN_BUSY	1'b1


always @(posedge PCLK)
begin
    if(!PRESETn)begin
	xs<=32'h0;
	xc<=32'h0;
	ys<=32'h0;
	yc<=32'h0;
	zs<=32'h0;
	zc<=32'h0;
	atan_state<=`ATAN_IDLE;
    end
    else begin
	case(atan_state)
	`ATAN_IDLE: begin
	    if(start)begin
		xs<=xs0;
		xc<=32'h0;
		ys<=ys0;
		yc<=32'h0;
		zs<=zs0;
		zc<=32'h0;
		atan_state<=`ATAN_BUSY;
	    end
	    else begin
	        atan_state<=`ATAN_IDLE;
	    end

	  end
	`ATAN_BUSY: begin
	    if(i!=5'd28)begin
		xs<=xs_out;
		xc<=xc_out;
		ys<=ys_out;
		yc<=yc_out;
		zs<=zs_out;
		zc<=zc_out;
	    	atan_state<=`ATAN_BUSY;
	    end
	    else begin
		atan_state<=`ATAN_IDLE;
	    end
	  end
	endcase
    end
end


Cd_online_e online0(.xs_in(xs),	
		  .xc_in(xc),	//has been shifted by 1	
		  .ys_in(ys),
		  .yc_in(yc),	//has been shifted by 1	
		  .zs_in(zs),
		  .zc_in(zc),	//has been shifted by 1	
		  .i(i),
		  .xs_out(xs_s1),
		  .xc_out(xc_s1),//has been shifted by 1	
		  .ys_out(ys_s1),
		  .yc_out(yc_s1),//has been shifted by 1	
		  .zs_out(zs_s1),
		  .zc_out(zc_s1) //has been shifted by 1	
);


assign i1=i|5'b1;  //instead i1=i+5'b1;

Cd_online_o online1(.xs_in(xs_s1),	
		  .xc_in(xc_s1),//has been shifted by 1	
		  .ys_in(ys_s1),
		  .yc_in(yc_s1),//has been shifted by 1	
		  .zs_in(zs_s1),
		  .zc_in(zc_s1),//has been shifted by 1	
		  .i(i1),
		  .xs_out(xs_out),
		  .xc_out(xc_out),//has been shifted by 1	
		  .ys_out(ys_out),
		  .yc_out(yc_out),//has been shifted by 1	
		  .zs_out(zs_out),
		  .zc_out(zc_out) //has been shifted by 1	
);



endmodule //Cd_atan




	




