//====================================================================
// NAME: cd_csa.v
// DESC: 4:2 carry save adder/subtractor
//       a+b or a-b
// HISTORY
// 12/02/2005: 
//	- first draft
// 12/03/2005:
//	- Cd_csa is optimized by spliting csa to cs_add and cs_sub
// 12/04/2005:
// 	- all c_out signals are not shifted inside module.
// 	- the MSB bit of the carry output of a carry_saver adder 
//        is not discarded because it should be used when ASR shift.
//====================================================================


module Cd_cs_add_4_2( 	a_s_in,
			a_c_in,  //a_c_in[0] should be 0.
		  	b_s_in,
		  	b_c_in,
		  	s_out,
		  	c_out	//c_out is not shifted
);

input [31:0] a_s_in,a_c_in,b_s_in,b_c_in;
output [31:0] s_out,c_out;

wire [31:0] tmp_s1,tmp_c1;

Cd_csa_3_2 csa_32_0 (.a1_in(a_s_in),
		     .a2_in(a_c_in),
		     .a3_in(b_s_in),
		     .s_out(tmp_s1),
		     .c_out(tmp_c1) 
		    );

Cd_csa_3_2 csa_32_1 (.a1_in(tmp_s1),
		     .a2_in({tmp_c1[30:0],1'b0}),
		     .a3_in(b_c_in),
		     .s_out(s_out),
		     .c_out(c_out) 
		    );

endmodule




module Cd_cs_sub_4_2( 	a_s_in,
			a_c_in,	//a_c_in[0] should be 0.
		  	b_s_in,
		  	b_c_in,
		  	s_out,
		  	c_out	//c_out is not shifted
);

input [31:0] a_s_in,a_c_in,b_s_in,b_c_in;
output [31:0] s_out,c_out;

wire [31:0] a1_tmp,a2_tmp,b1_tmp,b2_tmp;
wire [31:0] tmp_s1,tmp_c1;

assign b1_tmp = ~b_s_in;
assign b2_tmp = ~b_c_in;

Cd_csa_3_2 csa_32_0 (.a1_in(a_s_in),
		     .a2_in({a_c_in[31:1],1'b1}),
		     .a3_in(b1_tmp),
		     .s_out(tmp_s1),
		     .c_out(tmp_c1) 
		);

Cd_csa_3_2 csa_32_1 (.a1_in(tmp_s1),
		     .a2_in({tmp_c1[30:0],1'b1}),
		     .a3_in(b2_tmp),
		     .s_out(s_out),
		     .c_out(c_out) 
		);

endmodule



module Cd_cs_sub_3_2( 	a_s_in,
			a_c_in,
		  	b1_in,
		  	s_out,
		  	c_out	//c_out is not shifted
);

input [31:0] a_s_in,a_c_in,b1_in;
output [31:0] s_out,c_out;

wire [31:0] b1_tmp;

assign b1_tmp = ~b1_in;

Cd_csa_3_2 csa_32_0 (.a1_in(a_s_in),
		     .a2_in({a_c_in[31:1],1'b1}),
		     .a3_in(b1_tmp),
		     .s_out(s_out),
		     .c_out(c_out)  
		    );

endmodule




module Cd_csa_3_2(a1_in,
		 a2_in,
		 a3_in,
		 s_out,
		 c_out	//c_out is not shifted
);

input [31:0] a1_in,a2_in,a3_in;
output [31:0] s_out,c_out;

wire [31:0] c_tmp;
assign s_out = a1_in ^ a2_in ^ a3_in;
assign c_out = (a1_in & a2_in) | (a2_in & a3_in) | (a3_in & a1_in);

endmodule







	




