//====================================================================
// NAME: cd_main.v
// DESC: cordic main
// HISTORY
// 11/22/2005: 
//	- first draft
// 11/27/2005:
//      - booth-recoding is merged.
// 12/02/2005:
//	- hybrid on-line cordic is merged for atan() calculation.
//	- ATAN only function is added because the on-line cordic 
//        doesn't have the exact magnitude if sigma=0 is many.
//====================================================================



module Cd_main( PCLK,	
		PRESETn,
		reg_ctrl,
		reg_x_in,
		reg_y_in,
		reg_z_in,
		reg_x_out,
		reg_y_out,
		reg_z_out,
		reg_status
		);

input PCLK;
input PRESETn;

input [31:0] reg_ctrl;
input [31:0] reg_x_in;
input [31:0] reg_y_in;
input [31:0] reg_z_in;

output [31:0] reg_x_out;
output [31:0] reg_y_out;
output [31:0] reg_z_out;
output [31:0] reg_status;

wire rc_pend_clear = reg_ctrl[6];
wire rc_inten = reg_ctrl[5];
wire rc_start = reg_ctrl[0];
wire [3:0] rc_func = reg_ctrl[4:1]; 


wire [31:0] x_shift;
wire [31:0] y_shift;

wire [31:0] x_pass;
wire [31:0] y_pass;

wire [31:0] x_adder;
wire [31:0] y_adder;
wire [31:0] z_adder;


reg [31:0] x;
reg [31:0] y;
reg [31:0] z;
reg [31:0] zc;
reg [4:0] i;
reg [4:0] i_z;	//e(i_z)
reg [4:0] i_xy;

reg [4:0] i_xyz_d;
reg [4:0] i_next_d;
reg booth_sign_d;
reg booth_pass_d;

wire [4:0] i_xyz;
wire [4:0] i_next;
wire booth_sign;
wire booth_pass;
reg [31:0] booth_data_in;

wire [1:0] sigma,sigma2;
wire [31:0] e_i;
wire [31:0] adder_z_b_in;

reg interrupt;
reg int_gen;
reg [3:0] cdm_state;

reg pass_nzero;
reg add_x;
reg add_y;
reg add_z;

reg atan_start;
wire [31:0] zs_atan,zc_atan;

// CORDIC main states
`define CDM_IDLE		4'd0	
`define CDM_CR			4'd1 	//coarse rotation
`define CDM_SC_0		4'd2	//normal cordic
`define CDM_SC_1		4'd3	//booth recoding pre-calculation
`define CDM_SC_2		4'd4	//booth recoding & cordic
`define CDM_TN_0		4'd5	//hybrid online cordic
`define CDM_TN_1		4'd6    //aggregate the results.
`define CDM_MTN_0		4'd7	//normal cordic for atan()

`define FUNC_SINCOS		4'h1
`define FUNC_ROTATE		4'h2
`define FUNC_ATAN		4'h3
`define FUNC_MAG_ATAN		4'h4

always @(posedge PCLK)
begin
    if(!PRESETn)begin
	cdm_state<=4'b0;
	x<=32'h0;
	y<=32'h0;
	z<=32'h0;
	zc<=32'h0;
	i<=5'h0;
	booth_data_in<=32'h0;
	i_next_d<=5'h0;
    end
    else begin
	case(cdm_state)
	`CDM_IDLE:begin
	    if(rc_start)begin
		i<=5'd0;
		cdm_state<=`CDM_CR;
		if(rc_func==`FUNC_SINCOS)begin //sin,cos
		    x<=32'h136e9db5;
		    y<=32'h0;
		    z<=reg_z_in;
		end
		else if(rc_func==`FUNC_ATAN || rc_func==`FUNC_MAG_ATAN)begin 
		    x<=reg_x_in;
		    y<=reg_y_in;
		    z<=32'h0;
		end
		else begin
		    x<=reg_x_in;
		    y<=reg_y_in;
		    z<=reg_z_in;
 		end
	    end
	    else begin
		cdm_state<=`CDM_IDLE;
	    end
	  end
	`CDM_CR:begin	//coarse rotation
	    x<=x_adder;
	    y<=y_adder;
	    z<=z_adder;
	    i<=5'd0;
	    cdm_state<= (rc_func==`FUNC_SINCOS)?   `CDM_SC_0:
			(rc_func==`FUNC_ROTATE)?   `CDM_SC_0:
			(rc_func==`FUNC_ATAN)?     `CDM_TN_0:
			(rc_func==`FUNC_MAG_ATAN)? `CDM_MTN_0:`CDM_IDLE;
	  end	    
	`CDM_SC_0:begin // sin() & cos()
	    x<=x_adder;
	    y<=y_adder;
	    z<=z_adder;
	    if(i==5'd15)begin
		cdm_state<=`CDM_SC_1;
		i<=i+1;
		booth_data_in[31:0] <= z_adder[31:0];
			//<={10'b0,z_adder[21:0]};
			//<={10'b0,z_adder[31],z_adder[31],z_adder[19:0]};
	        i_next_d<=5'd14;
	    end	
	    else begin
		i<=i+1;
		cdm_state<=`CDM_SC_0;
	    end
	  end

	`CDM_SC_1:begin
	    i<=5'd14;
	    i_next_d<=i_next;
	    i_xyz_d<=i_xyz;
	    booth_sign_d <=booth_sign;
	    booth_pass_d <=booth_pass; 
	    cdm_state<=`CDM_SC_2;
	  end 

	`CDM_SC_2:begin
	    if(booth_pass_d==1'b0)begin
	        x<=x_adder;
	    	y<=y_adder;
	    	z<=z_adder;
	    end
	    i_next_d<=i_next;
	    i_xyz_d<=i_xyz;
	    booth_sign_d <=booth_sign;
	    booth_pass_d <=booth_pass; 
	    if(i==28 || i_next_d==30)begin
	 	cdm_state<=`CDM_IDLE;
   	    end
	    else begin
		i<=i_next_d;
		cdm_state<=`CDM_SC_2;
	    end
	  end
	`CDM_TN_0:begin //arctan() & magnitude
	    if(i<5'd28)begin
	    	i<=i+5'd2;
		cdm_state<=`CDM_TN_0;
	    end
	    else begin
		cdm_state<=`CDM_TN_1;
	    	z<=zs_atan;
		zc<={zc_atan[30:0],1'b0};
	    end	   	
	  end
	`CDM_TN_1:begin
	    x<=32'b0;
	    y<=32'b0;
	    z<=z_adder;
	    cdm_state<=`CDM_IDLE;
	  end
	`CDM_MTN_0:begin //arctan() & magnitude
	    x<=x_adder;
	    y<=y_adder;
	    z<=z_adder;
	    if(i==29)
		cdm_state<=`CDM_IDLE;
	    else begin
		i<=i+1;
		cdm_state<=`CDM_MTN_0;
	    end
	  end
	default:
	    cdm_state<=`CDM_IDLE;
	endcase
    end
end



assign sigma = 
	(rc_func==`FUNC_SINCOS || rc_func==`FUNC_ROTATE )
					?((z[31]==1'b0)?2'b01:2'b11): 
	(rc_func==`FUNC_ATAN || rc_func==`FUNC_MAG_ATAN )
					?((y[31]==1'b0)?2'b11:2'b01):2'b00;

assign sigma2 = 
	(rc_func==`FUNC_SINCOS || rc_func==`FUNC_ROTATE )
				?((booth_sign_d==1'b0)?2'b01:2'b11): 
	(rc_func==`FUNC_ATAN || rc_func==`FUNC_MAG_ATAN )
				?((booth_sign_d==1'b0)?2'b11:2'b01):2'b00;


	
always @(cdm_state or y or z or i or sigma or rc_func or rc_start 
	 or booth_sign_d or sigma2 or i_next_d or i_xyz_d)
begin
    case(cdm_state)
    `CDM_IDLE:begin
	pass_nzero<=1'b1;
	add_x<=1;  //for atan final result calculation, should be 1 
	add_y<=1;  //for atan final result calculation, should be 1 
	add_z<=1;  //for atan final result calculation, should be 1 
	int_gen<=0;
	i_z<=5'd0;
	i_xy<=5'd0;
	atan_start<=1'b0;
      end
    `CDM_CR:begin
	int_gen<=0;
	i_z<=5'd31;
	i_xy<=5'd0;

	if( rc_func==`FUNC_ATAN ) 
	    atan_start<=1'b1;
	else
	    atan_start<=1'b0;
	
	if( (z[31]==1'b0 && (rc_func==`FUNC_SINCOS||rc_func==`FUNC_ROTATE ))||
	    (y[31]==1'b1 && (rc_func==`FUNC_ATAN||rc_func==`FUNC_MAG_ATAN)) )
	begin
	    pass_nzero<=1'b0;
	    add_x<=1'b0;
	    add_y<=1'b1;
	    add_z<=1'b0;
	end
	else begin
	    pass_nzero<=1'b0;
	    add_x<=1'b1;
	    add_y<=1'b0;
	    add_z<=1'b1;
	end
      end
    `CDM_SC_0:begin
	int_gen<= 1'b0;
	i_z <= i;
	i_xy <= i;
	pass_nzero<=1'b1;
	add_x<= (sigma==2'b01) ? 1'b0:1'b1;
	add_y<= (sigma==2'b01) ? 1'b1:1'b0;
	add_z<= (sigma==2'b01) ? 1'b0:1'b1;
	atan_start<=1'b0;
      end
    `CDM_SC_1:begin
	int_gen<= 1'b0;
	pass_nzero<=1'b1;
	i_z  <= i;
	i_xy <= i;
	add_x<= 1'b1;  //adder outputs will be discarded.
	add_y<= 1'b1;
	add_z<= 1'b1;
	atan_start<=1'b0;
      end
    `CDM_SC_2:begin
	int_gen<= (i==28 || i_next_d==30)?1'b1:1'b0;
	i_z <= i_xyz_d;
	i_xy<= i_xyz_d;
	pass_nzero<=1'b1;
	add_x<= (sigma2==2'b01) ? 1'b0:1'b1;
	add_y<= (sigma2==2'b01) ? 1'b1:1'b0;
	add_z<= (sigma2==2'b01) ? 1'b0:1'b1;
	atan_start<=1'b0;
      end
    `CDM_TN_0:begin
	int_gen<=1'b0;
	i_z <= 5'b0;	//don't care
	i_xy<= 5'b0;	//don't care
	pass_nzero<=1'b1;
	add_x<= 1'b1;
	add_y<= 1'b1;
	add_z<= 1'b1;
	atan_start<=1'b0;
      end
    `CDM_TN_1:begin
	int_gen<=1'b1;
	i_z <= 5'b0;	//don't care
	i_xy<= 5'b0;	//don't care
	pass_nzero<=1'b1;
	add_x<= 1'b1;	
	add_y<= 1'b1;
	add_z<= 1'b1;
	atan_start<=1'b0;
      end
    `CDM_MTN_0:begin
	int_gen<= (i==29)?1'b1:1'b0;
	i_z <= i;
	i_xy<= i;
	pass_nzero<=1'b1;
	add_x<= (sigma==2'b01) ? 1'b0:1'b1;
	add_y<= (sigma==2'b01) ? 1'b1:1'b0;
	add_z<= (sigma==2'b01) ? 1'b0:1'b1;
	atan_start<=1'b0;
      end
    default:begin
	int_gen<=1'b0;
	i_z<=i;
	i_xy<=i;
	pass_nzero<=1'b0;
	add_x<=0;
	add_y<=0;
	add_z<=0;
	atan_start<=1'b0;
      end
    endcase
end




always @(posedge PCLK)
begin
    if(!PRESETn)begin
	interrupt=1'b0;
    end
    else begin
	if(int_gen)
	    interrupt=1'b1;
	else if(rc_pend_clear)
	    interrupt=1'b0;
    end
end



assign x_pass = (pass_nzero)? x:32'b0;
assign y_pass = (pass_nzero)? y:32'b0;

assign reg_x_out = x_pass;
assign reg_y_out = y_pass;
assign reg_z_out = z;
assign reg_status = {31'b0,interrupt};



Cd_shifter shifter_x(.a_in(x),
		     .b_out(x_shift),
		     .shift_count(i_xy)
	 	    );

Cd_shifter shifter_y(.a_in(y),
		     .b_out(y_shift),
		     .shift_count(i_xy)
		     );

Cd_adder adder_x(.a_in(x_pass),
		 .b_in(y_shift),
		 .add_nsub(add_x),
		 .s_out(x_adder)
		);

Cd_adder adder_y(.a_in(y_pass),
		 .b_in(x_shift),
		 .add_nsub(add_y),
		 .s_out(y_adder)
		);

Cd_adder adder_z(.a_in(z),
		 .b_in(adder_z_b_in),
		 .add_nsub(add_z),
		 .s_out(z_adder)
		);


Cd_z_table e_table(.i(i_z),
		   .e_i(e_i)
);

assign adder_z_b_in = (cdm_state==`CDM_TN_1)? zc:e_i;

Cd_booth_recoding booth_recoding(
		  .data_in(booth_data_in),
		  .i_in(i_next_d),
		  .i_next(i_next),
		  .i_xyz(i_xyz),
		  .sign(booth_sign),
		  .pass(booth_pass)
		 );


Cd_atan atan(	.PCLK(PCLK),
		.PRESETn(PRESETn),
		.xs0(x_adder),
		.ys0(y_adder),
		.zs0(z_adder),
		.i(i),
		.start(atan_start),
		.xs_out(),	
		.xc_out(), 	  //xc_out<<1 inside the module
		.zs_out(zs_atan),
		.zc_out(zc_atan)  //zc_out<<1 inside the module
);
	
endmodule







