//====================================================================
// NAME: cd_online.v
// DESC: 1-stage online cordic module
// HISTORY
// 12/02/2005: 
//	- first draft
// 12/03/2005:
//      - Cd_online module is optimized each for even and odd cases.
// 12/03/2005
//      - sigma-selection based online cordic for speed-up
//====================================================================



//=======================================================
// Cd_online_e
//=======================================================
module Cd_online_e( xs_in,
		  xc_in,	
		  ys_in,
		  yc_in,	
		  zs_in,
		  zc_in,	
		  i,
		  xs_out,	
		  xc_out,	
		  ys_out,
		  yc_out,	
		  zs_out,
		  zc_out	
);

input [31:0] xs_in,xc_in,ys_in,yc_in,zs_in,zc_in;
input [4:0] i;
output [31:0] xs_out,xc_out,ys_out,yc_out,zs_out,zc_out; 

wire [31:0] e_i;

//wire add_x,add_y,add_z;
wire [1:0] sigma;

wire [31:0] xs_shift,xc_shift,ys_shift,yc_shift;
//wire [31:0] xs_pass,xc_pass,ys_pass,yc_pass;
wire [31:0] xs_sigma_p1,xc_sigma_p1,xs_sigma_n1,xc_sigma_n1;
wire [31:0] ys_sigma_p1,yc_sigma_p1,ys_sigma_n1,yc_sigma_n1;
wire [31:0] zs_sigma_p1,zc_sigma_p1,zs_sigma_n1,zc_sigma_n1;

//wire [31:0] e_i_pass;

wire [31:0] xc_out_tmp,yc_out_tmp,zc_out_tmp;

wire [3:0] ys_4bit,yc_4bit;

wire check_xs31xc30,check_ys31yc30;
wire xs_31,xc_30,ys_31,yc_30;

Cd_sigma_pred_ex sigma_pred_ex(
		         .ys_4bit(ys_4bit),
			 .yc_4bit(yc_4bit),
		  	 .add_x(),
			 .add_y(),
			 .add_z(),
			 .sigma(sigma)
);


Cd_sigma_4bit_e sigma_ys_4bit( .a_in(ys_in),
		               .i(i),	//even number
			       .b_4bit(ys_4bit)
);


Cd_sigma_4bit_e sigma_yc_4bit( .a_in({yc_in[30:0],1'b0}),
		               .i(i),	//even number
			       .b_4bit(yc_4bit)
);


assign check_xs31xc30 = ~(xs_in[31] && xc_in[30]);
assign check_ys31yc30 = ~(ys_in[31] && yc_in[30]);
assign xs_31=xs_in[31] & check_xs31xc30;
assign xc_30=xc_in[30] & check_xs31xc30;
assign ys_31=ys_in[31] & check_ys31yc30;
assign yc_30=yc_in[30] & check_ys31yc30;

//xs_in should be shifted by ASR shifter.
Cd_shifter xs_shifter( 
	.a_in({xs_31,xs_in[30:0]}),
	.b_out(xs_shift),
	.shift_count(i) //right shift count
	);

Cd_shifter xc_shifter(
	.a_in({xc_30,xc_30,xc_in[29:0]}),
	.b_out(xc_shift),
	.shift_count(i) //right shift count
	);



//ys_in should be shifted by ASR shifter.
Cd_shifter ys_shifter( 
	.a_in({ys_31,ys_in[30:0]}),
	.b_out(ys_shift),
	.shift_count(i) //right shift count
	);

Cd_shifter yc_shifter(
	.a_in({yc_30,yc_30,yc_in[29:0]}),
	.b_out(yc_shift),
	.shift_count(i) //right shift count
	);

//assign xs_pass = (sigma==2'b0)? 32'b0:xs_shift;
//assign xc_pass = (sigma==2'b0)? 32'b0:xc_shift;
//assign ys_pass = (sigma==2'b0)? 32'b0:ys_shift;
//assign yc_pass = (sigma==2'b0)? 32'b0:yc_shift;
//assign e_i_pass= (sigma==2'b0)? 32'b0:e_i;


//sigma add_x add_y add_z
// -1     1     0     1
//  0     1     1     1
//  1     0     1     0


assign xs_out = (sigma==2'b01)? xs_sigma_p1:
		(sigma==2'b11)? xs_sigma_n1:xs_in;
assign xc_out = (sigma==2'b01)? xc_sigma_p1:
		(sigma==2'b11)? xc_sigma_n1:xc_in;

// sigma==1
Cd_cs_sub_4_2 cs_sub42_x0(.a_s_in(xs_in),
			  .a_c_in({xc_in[30:0],1'b0}),
		  	  .b_s_in(ys_shift),
		  	  .b_c_in({yc_shift[30:0],1'b0}),
		  	  .s_out(xs_sigma_p1),
		  	  .c_out(xc_sigma_p1)	
);

// sigma==-1
Cd_cs_add_4_2 cs_add42_x1(.a_s_in(xs_in),
			  .a_c_in({xc_in[30:0],1'b0}),
		  	  .b_s_in(ys_shift),
		  	  .b_c_in({yc_shift[30:0],1'b0}),
		  	  .s_out(xs_sigma_n1),
		  	  .c_out(xc_sigma_n1)	
);




assign ys_out = (sigma==2'b01)? ys_sigma_p1:
		(sigma==2'b11)? ys_sigma_n1:ys_in;
assign yc_out = (sigma==2'b01)? yc_sigma_p1:
		(sigma==2'b11)? yc_sigma_n1:yc_in;

// sgima==1
Cd_cs_add_4_2 cs_add42_y0(.a_s_in(ys_in),
			  .a_c_in({yc_in[30:0],1'b0}),
		  	  .b_s_in(xs_shift),
		  	  .b_c_in({xc_shift[30:0],1'b0}),
		  	  .s_out(ys_sigma_p1),
		  	  .c_out(yc_sigma_p1)	
);

// sigma==-1
Cd_cs_sub_4_2 cs_sub42_y1(.a_s_in(ys_in),
			  .a_c_in({yc_in[30:0],1'b0}),
		  	  .b_s_in(xs_shift),
		  	  .b_c_in({xc_shift[30:0],1'b0}),
		  	  .s_out(ys_sigma_n1),
		  	  .c_out(yc_sigma_n1)	
);


assign zs_out = (sigma==2'b01)? zs_sigma_p1:
		(sigma==2'b11)? zs_sigma_n1:zs_in;
assign zc_out = (sigma==2'b01)? zc_sigma_p1:
		(sigma==2'b11)? zc_sigma_n1:zc_in;
// sigma==1
Cd_cs_sub_3_2 cs_sub32_z0(.a_s_in(zs_in),
			  .a_c_in({zc_in[30:0],1'b0}),
		  	  .b1_in(e_i),
		  	  .s_out(zs_sigma_p1),
		  	  .c_out(zc_sigma_p1)	//c_out has been shifted by 1
);

// sigma==-1
Cd_csa_3_2 cs_add32_z1( .a1_in(zs_in),
			.a2_in({zc_in[30:0],1'b0}),
		  	.a3_in(e_i),
		  	.s_out(zs_sigma_n1),
		  	.c_out(zc_sigma_n1)	//c_out has been shifted by 1
);

Cd_z_even_table z_table( .i(i),
			 .e_i(e_i)
);


endmodule





//=======================================================
// Cd_online_o
//=======================================================
module Cd_online_o( xs_in,
		  xc_in,	
		  ys_in,
		  yc_in,	
		  zs_in,
		  zc_in,	
		  i,
		  xs_out,	
		  xc_out,	
		  ys_out,
		  yc_out,	
		  zs_out,
		  zc_out	
);

input [31:0] xs_in,xc_in,ys_in,yc_in,zs_in,zc_in;
input [4:0] i;
output [31:0] xs_out,xc_out,ys_out,yc_out,zs_out,zc_out; 

wire [31:0] e_i;

//wire add_x,add_y,add_z;
wire [1:0] sigma;

wire [31:0] xs_shift,xc_shift,ys_shift,yc_shift;
//wire [31:0] xs_pass,xc_pass,ys_pass,yc_pass;
//wire [31:0] e_i_pass;
wire [31:0] xs_sigma_p1,xc_sigma_p1,xs_sigma_n1,xc_sigma_n1;
wire [31:0] ys_sigma_p1,yc_sigma_p1,ys_sigma_n1,yc_sigma_n1;
wire [31:0] zs_sigma_p1,zc_sigma_p1,zs_sigma_n1,zc_sigma_n1;

wire [31:0] xc_out_tmp,yc_out_tmp,zc_out_tmp;

wire [3:0] ys_4bit,yc_4bit;

wire check_xs31xc30,check_ys31yc30;
wire xs_31,xc_30,ys_31,yc_30;



Cd_sigma_pred_ex sigma_pred(
		         .ys_4bit(ys_4bit),
			 .yc_4bit(yc_4bit),
		  	 .add_x(),
			 .add_y(),
			 .add_z(),
			 .sigma(sigma)
);


Cd_sigma_4bit_o sigma_ys_4bit( .a_in(ys_in),
		               .i(i),	//odd number
			       .b_4bit(ys_4bit)
);


Cd_sigma_4bit_o sigma_yc_4bit( .a_in({yc_in[30:0],1'b0}),
		               .i(i),	//odd number
			       .b_4bit(yc_4bit)
);



assign check_xs31xc30 = ~(xs_in[31] && xc_in[30]);
assign check_ys31yc30 = ~(ys_in[31] && yc_in[30]);
assign xs_31=xs_in[31] & check_xs31xc30;
assign xc_30=xc_in[30] & check_xs31xc30;
assign ys_31=ys_in[31] & check_ys31yc30;
assign yc_30=yc_in[30] & check_ys31yc30;

//xs_in should be shifted by ASR shifter.
Cd_shifter xs_shifter( 
	.a_in({xs_31,xs_in[30:0]}),
	.b_out(xs_shift),
	.shift_count(i) //right shift count
	);

Cd_shifter xc_shifter(
	.a_in({xc_30,xc_30,xc_in[29:0]}),
	.b_out(xc_shift),
	.shift_count(i) //right shift count
	);

//ys_in should be shifted by ASR shifter.
Cd_shifter ys_shifter( 
	.a_in({ys_31,ys_in[30:0]}),
	.b_out(ys_shift),
	.shift_count(i) //right shift count
	);

Cd_shifter yc_shifter(
	.a_in({yc_30,yc_30,yc_in[29:0]}),
	.b_out(yc_shift),
	.shift_count(i) //right shift count
	);


//sigma add_x add_y add_z
// -1     1     0     1
//  0     1     1     1
//  1     0     1     0


assign xs_out = (sigma==2'b01)? xs_sigma_p1:
		(sigma==2'b11)? xs_sigma_n1:xs_in;
assign xc_out = (sigma==2'b01)? xc_sigma_p1:
		(sigma==2'b11)? xc_sigma_n1:xc_in;

// sigma==1
Cd_cs_sub_4_2 cs_sub42_x0(.a_s_in(xs_in),
			.a_c_in({xc_in[30:0],1'b0}),
		  	.b_s_in(ys_shift),
		  	.b_c_in({yc_shift[30:0],1'b0}),
		  	.s_out(xs_sigma_p1),
		  	.c_out(xc_sigma_p1)	//c_out has been shifted by 1
);

// sigma==-1
Cd_cs_add_4_2 cs_add42_x1(.a_s_in(xs_in),
			.a_c_in({xc_in[30:0],1'b0}),
		  	.b_s_in(ys_shift),
		  	.b_c_in({yc_shift[30:0],1'b0}),
		  	.s_out(xs_sigma_n1),
		  	.c_out(xc_sigma_n1)	//c_out has been shifted by 1
);




assign ys_out = (sigma==2'b01)? ys_sigma_p1:
		(sigma==2'b11)? ys_sigma_n1:ys_in;
assign yc_out = (sigma==2'b01)? yc_sigma_p1:
		(sigma==2'b11)? yc_sigma_n1:yc_in;

// sgima==1
Cd_cs_add_4_2 cs_add42_y0(.a_s_in(ys_in),
			.a_c_in({yc_in[30:0],1'b0}),
		  	.b_s_in(xs_shift),
		  	.b_c_in({xc_shift[30:0],1'b0}),
		  	.s_out(ys_sigma_p1),
		  	.c_out(yc_sigma_p1)	//c_out has been shifted by 1
);

// sigma==-1
Cd_cs_sub_4_2 cs_sub42_y1(.a_s_in(ys_in),
			.a_c_in({yc_in[30:0],1'b0}),
		  	.b_s_in(xs_shift),
		  	.b_c_in({xc_shift[30:0],1'b0}),
		  	.s_out(ys_sigma_n1),
		  	.c_out(yc_sigma_n1)	//c_out has been shifted by 1
);


assign zs_out = (sigma==2'b01)? zs_sigma_p1:
		(sigma==2'b11)? zs_sigma_n1:zs_in;
assign zc_out = (sigma==2'b01)? zc_sigma_p1:
		(sigma==2'b11)? zc_sigma_n1:zc_in;
// sigma==1
Cd_cs_sub_3_2 cs_sub32_z0(.a_s_in(zs_in),
			  .a_c_in({zc_in[30:0],1'b0}),
		  	  .b1_in(e_i),
		  	  .s_out(zs_sigma_p1),
		  	  .c_out(zc_sigma_p1)	//c_out has been shifted by 1
);

// sigma==-1
Cd_csa_3_2 cs_add32_z1( .a1_in(zs_in),
			.a2_in({zc_in[30:0],1'b0}),
		  	.a3_in(e_i),
		  	.s_out(zs_sigma_n1),
		  	.c_out(zc_sigma_n1)	//c_out has been shifted by 1
);

Cd_z_odd_table z_table( .i(i),
			.e_i(e_i)
);




endmodule










	




