//====================================================================
// NAME: cd_sigma_pred.v
// DESC: sigma prediction block for cd_online.v
// HISTORY
// 12/02/2005: 
//	- first draft
//====================================================================

/*
module Cd_sigma_pred( 	ys_in,
			yc_in,
		  	i,
		  	add_x,
			add_y,
			add_z,
			sigma
);

input [31:0] ys_in,yc_in;
input [4:0] i;
output add_x,add_y,add_z;
output [1:0] sigma;

wire [3:0] ys_4bit,yc_4bit;
wire [31:0] ys_shift,yc_shift;
wire [3:0] sum_y;

reg [1:0] sigma;
reg add_x,add_y,add_z;

assign ys_shift = (ys_in <<i);
assign ys_4bit = ys_shift[31:28];

assign yc_shift = (yc_in <<i);
assign yc_4bit = yc_shift[31:28];

assign sum_y = ys_4bit + yc_4bit; 
   // we make sure that the overflow will not occur
   //because the maximum values are predicted for each stage.

always @(sum_y)begin
    if(sum_y[3]==1'b0)begin
	//y_pred >=0: sigma = -1
   	sigma<=2'b11;
	add_x<=1'b1;
	add_y<=1'b0;
	add_z<=1'b1;
    end
    else if(sum_y==4'b1111)begin //sum_y == -1 : sigma = 0
	sigma<=2'b00;
	add_x<=1'b1;
	add_y<=1'b1;
	add_z<=1'b1;
    end
    else begin	//sum_y <=-2: sigma = +1
	sigma<=2'b01;
	add_x<=1'b0;
	add_y<=1'b1;
	add_z<=1'b0;
    end
end

endmodule
*/



//=======================================================
// Cd_sigma_4bit_e
//=======================================================
module Cd_sigma_4bit_e (a_in,
		        i,	//even number
			b_4bit
);
input [31:0] a_in;
input [4:0] i;
output [3:0] b_4bit;

reg [3:0] b_4bit;

always @(a_in or i)
begin
    case(i)
    5'd0: b_4bit = a_in[31:28];
    5'd2: b_4bit = a_in[29:26];
    5'd4: b_4bit = a_in[27:24];
    5'd6: b_4bit = a_in[25:22];
    5'd8: b_4bit = a_in[23:20];
    5'd10: b_4bit = a_in[21:18];
    5'd12: b_4bit = a_in[19:16];
    5'd14: b_4bit = a_in[17:14];
    5'd16: b_4bit = a_in[15:12];
    5'd18: b_4bit = a_in[13:10];
    5'd20: b_4bit = a_in[11:8];
    5'd22: b_4bit = a_in[9:6];
    5'd24: b_4bit = a_in[7:4];
    5'd26: b_4bit = a_in[5:2];
    5'd28: b_4bit = a_in[3:0];
    default: b_4bit = 4'bxxxx;
    endcase
end

endmodule



//=======================================================
// Cd_sigma_4bit_o
//=======================================================
module Cd_sigma_4bit_o (a_in,
		        i,	//odd number
			b_4bit
);
input [31:0] a_in;
input [4:0] i;
output [3:0] b_4bit;

reg [3:0] b_4bit;

always @(a_in or i)
begin
    case(i)
    5'd1: b_4bit = a_in[30:27];
    5'd3: b_4bit = a_in[28:25];
    5'd5: b_4bit = a_in[26:23];
    5'd7: b_4bit = a_in[24:21];
    5'd9: b_4bit = a_in[22:19];
    5'd11: b_4bit = a_in[20:17];
    5'd13: b_4bit = a_in[18:15];
    5'd15: b_4bit = a_in[16:13];
    5'd17: b_4bit = a_in[14:11];
    5'd19: b_4bit = a_in[12:9];
    5'd21: b_4bit = a_in[10:7];
    5'd23: b_4bit = a_in[8:5];
    5'd25: b_4bit = a_in[6:3];
    5'd27: b_4bit = a_in[4:1];
    5'd29: b_4bit = {a_in[2:0],1'b0};
    default: b_4bit = 4'bxxxx;
    endcase
end

endmodule


		      
//=======================================================
//  Cd_sigma_pred_ex
//=======================================================
module Cd_sigma_pred_ex(
			ys_4bit,
			yc_4bit,
		  	add_x,
			add_y,
			add_z,
			sigma
);
input [3:0] ys_4bit,yc_4bit;
output add_x,add_y,add_z;
output [1:0] sigma;

wire [3:0] ys_4bit,yc_4bit;
wire [31:0] ys_shift,yc_shift;
wire [3:0] sum_y;

reg [1:0] sigma;
reg add_x,add_y,add_z;


assign sum_y = ys_4bit + yc_4bit; 
   // we make sure that the overflow will not occur
   //because the maximum values are predicted for each stage.

always @(sum_y)begin
    if(sum_y[3]==1'b0)begin
	//y_pred >=0: sigma = -1
   	sigma<=2'b11;
	add_x<=1'b1;
	add_y<=1'b0;
	add_z<=1'b1;
    end
    else if(sum_y==4'b1111)begin //sum_y == -1 : sigma = 0
	sigma<=2'b00;
	add_x<=1'b1;
	add_y<=1'b1;
	add_z<=1'b1;
    end
    else begin	//sum_y <=-2: sigma = +1
	sigma<=2'b01;
	add_x<=1'b0;
	add_y<=1'b1;
	add_z<=1'b0;
    end
end

endmodule







	




