`timescale 1ns/10ps

module cd_test;

reg PCLK;
reg PRESETn;
reg PSEL;
reg PENABLE;
reg [4:0] PADDR;
reg PWRITE;
reg [31:0] PWDATA;
wire [31:0] PRDATA;
wire INT;


// cordic address map
`define CTRL 		5'h0
`define X_IN 		5'h4
`define Y_IN  		5'h8
`define Z_IN		5'hc
`define X_OUT		5'h10
`define Y_OUT		5'h14
`define Z_OUT		5'h18
`define STATUS		5'h1c

`define RAD_60		32'h2182a470
`define RAD_120		32'h430548e0
`define RAD_N60		(~`RAD_60+32'h1)
`define RAD_N120	(~`RAD_120+32'h1)
`define RAD_45		32'h1921fb54
`define RAD_N45		(~`RAD_45+32'h1)
`define RAD_135		32'h4b65f1fc
`define RAD_N135	(~`RAD_135+32'h1)
	
`define ROOT_P5		32'h16a09e66
`define NROOT_P5	(~`ROOT_P5+32'h1)
`define COS_60		32'h10000000
`define NCOS_60		(~`COS_60+32'h1)
`define SIN_60		32'h1bb67ae8
`define NSIN_60		(~`SIN_60+32'h1)
`define ONE_BY_R	32'h136e9db5
`define R		32'h34b24291

`define CMD_SINCOS	32'h00000023
`define CMD_ROTATE	32'h00000025
`define CMD_ATAN	32'h00000027
`define CMD_MAG_ATAN	32'h00000029
`define CMD_CLEARPEND   32'h00000040
`define DONTCARE	32'h7fffffff

initial begin
    PCLK=0;
    PRESETn=0;
    @(posedge PCLK);
    @(posedge PCLK);
    PRESETn=1;

    // cos, sin(-180)
    CMD_CORDIC(32'h0, 32'h0, 32'h9b7812af , `CMD_SINCOS, 
              32'he0000000, 32'h00000000, 32'h0 );

    // cos, sin(-179)
    CMD_CORDIC(32'h0, 32'h0, 32'h9c070ce5 , `CMD_SINCOS, 
              32'he0013f69, 32'hff7107a7, 32'h0 );

    // cos, sin(-178)
    CMD_CORDIC(32'h0, 32'h0, 32'h9c96071a , `CMD_SINCOS, 
              32'he004fd88, 32'hfee21a74, 32'h0 );

    // cos, sin(-177)
    CMD_CORDIC(32'h0, 32'h0, 32'h9d25014f , `CMD_SINCOS, 
              32'he00b3a13, 32'hfe53438c, 32'h0 );

    // cos, sin(-176)
    CMD_CORDIC(32'h0, 32'h0, 32'h9db3fb84 , `CMD_SINCOS, 
              32'he013f48f, 32'hfdc48e13, 32'h0 );

    // cos, sin(-175)
    CMD_CORDIC(32'h0, 32'h0, 32'h9e42f5b9 , `CMD_SINCOS, 
              32'he01f2c4c, 32'hfd360529, 32'h0 );

    // cos, sin(-174)
    CMD_CORDIC(32'h0, 32'h0, 32'h9ed1efee , `CMD_SINCOS, 
              32'he02ce06c, 32'hfca7b3ed, 32'h0 );

    // cos, sin(-173)
    CMD_CORDIC(32'h0, 32'h0, 32'h9f60ea23 , `CMD_SINCOS, 
              32'he03d0fdb, 32'hfc19a577, 32'h0 );

    // cos, sin(-172)
    CMD_CORDIC(32'h0, 32'h0, 32'h9fefe458 , `CMD_SINCOS, 
              32'he04fb957, 32'hfb8be4db, 32'h0 );

    // cos, sin(-171)
    CMD_CORDIC(32'h0, 32'h0, 32'ha07ede8d , `CMD_SINCOS, 
              32'he064db6c, 32'hfafe7d27, 32'h0 );

    // cos, sin(-170)
    CMD_CORDIC(32'h0, 32'h0, 32'ha10dd8c2 , `CMD_SINCOS, 
              32'he07c7474, 32'hfa717961, 32'h0 );

    // cos, sin(-169)
    CMD_CORDIC(32'h0, 32'h0, 32'ha19cd2f7 , `CMD_SINCOS, 
              32'he0968297, 32'hf9e4e489, 32'h0 );

    // cos, sin(-168)
    CMD_CORDIC(32'h0, 32'h0, 32'ha22bcd2c , `CMD_SINCOS, 
              32'he0b303ce, 32'hf958c995, 32'h0 );

    // cos, sin(-167)
    CMD_CORDIC(32'h0, 32'h0, 32'ha2bac761 , `CMD_SINCOS, 
              32'he0d1f5df, 32'hf8cd3373, 32'h0 );

    // cos, sin(-166)
    CMD_CORDIC(32'h0, 32'h0, 32'ha349c196 , `CMD_SINCOS, 
              32'he0f35661, 32'hf8422d04, 32'h0 );

    // cos, sin(-165)
    CMD_CORDIC(32'h0, 32'h0, 32'ha3d8bbcc , `CMD_SINCOS, 
              32'he11722b9, 32'hf7b7c120, 32'h0 );

    // cos, sin(-164)
    CMD_CORDIC(32'h0, 32'h0, 32'ha467b601 , `CMD_SINCOS, 
              32'he13d581d, 32'hf72dfa92, 32'h0 );

    // cos, sin(-163)
    CMD_CORDIC(32'h0, 32'h0, 32'ha4f6b036 , `CMD_SINCOS, 
              32'he165f392, 32'hf6a4e419, 32'h0 );

    // cos, sin(-162)
    CMD_CORDIC(32'h0, 32'h0, 32'ha585aa6b , `CMD_SINCOS, 
              32'he190f1ed, 32'hf61c8865, 32'h0 );

    // cos, sin(-161)
    CMD_CORDIC(32'h0, 32'h0, 32'ha614a4a0 , `CMD_SINCOS, 
              32'he1be4fd5, 32'hf594f218, 32'h0 );

    // cos, sin(-160)
    CMD_CORDIC(32'h0, 32'h0, 32'ha6a39ed5 , `CMD_SINCOS, 
              32'he1ee09be, 32'hf50e2bc6, 32'h0 );

    // cos, sin(-159)
    CMD_CORDIC(32'h0, 32'h0, 32'ha732990a , `CMD_SINCOS, 
              32'he2201bf2, 32'hf4883ff1, 32'h0 );

    // cos, sin(-158)
    CMD_CORDIC(32'h0, 32'h0, 32'ha7c1933f , `CMD_SINCOS, 
              32'he2548287, 32'hf4033909, 32'h0 );

    // cos, sin(-157)
    CMD_CORDIC(32'h0, 32'h0, 32'ha8508d74 , `CMD_SINCOS, 
              32'he28b3968, 32'hf37f216f, 32'h0 );

    // cos, sin(-156)
    CMD_CORDIC(32'h0, 32'h0, 32'ha8df87a9 , `CMD_SINCOS, 
              32'he2c43c52, 32'hf2fc0370, 32'h0 );

    // cos, sin(-155)
    CMD_CORDIC(32'h0, 32'h0, 32'ha96e81de , `CMD_SINCOS, 
              32'he2ff86d0, 32'hf279e945, 32'h0 );

    // cos, sin(-154)
    CMD_CORDIC(32'h0, 32'h0, 32'ha9fd7c13 , `CMD_SINCOS, 
              32'he33d1445, 32'hf1f8dd13, 32'h0 );

    // cos, sin(-153)
    CMD_CORDIC(32'h0, 32'h0, 32'haa8c7648 , `CMD_SINCOS, 
              32'he37cdfe3, 32'hf178e8eb, 32'h0 );

    // cos, sin(-152)
    CMD_CORDIC(32'h0, 32'h0, 32'hab1b707d , `CMD_SINCOS, 
              32'he3bee4b1, 32'hf0fa16c6, 32'h0 );

    // cos, sin(-151)
    CMD_CORDIC(32'h0, 32'h0, 32'habaa6ab3 , `CMD_SINCOS, 
              32'he4031d89, 32'hf07c708a, 32'h0 );

    // cos, sin(-150)
    CMD_CORDIC(32'h0, 32'h0, 32'hac3964e8 , `CMD_SINCOS, 
              32'he4498518, 32'hf0000001, 32'h0 );

    // cos, sin(-149)
    CMD_CORDIC(32'h0, 32'h0, 32'hacc85f1d , `CMD_SINCOS, 
              32'he49215e2, 32'hef84cee0, 32'h0 );

    // cos, sin(-148)
    CMD_CORDIC(32'h0, 32'h0, 32'had575952 , `CMD_SINCOS, 
              32'he4dcca3e, 32'hef0ae6c2, 32'h0 );

    // cos, sin(-147)
    CMD_CORDIC(32'h0, 32'h0, 32'hade65387 , `CMD_SINCOS, 
              32'he5299c58, 32'hee925129, 32'h0 );

    // cos, sin(-146)
    CMD_CORDIC(32'h0, 32'h0, 32'hae754dbc , `CMD_SINCOS, 
              32'he5788633, 32'hee1b177c, 32'h0 );

    // cos, sin(-145)
    CMD_CORDIC(32'h0, 32'h0, 32'haf0447f1 , `CMD_SINCOS, 
              32'he5c981a7, 32'heda54308, 32'h0 );

    // cos, sin(-144)
    CMD_CORDIC(32'h0, 32'h0, 32'haf934226 , `CMD_SINCOS, 
              32'he61c8865, 32'hed30dcfc, 32'h0 );

    // cos, sin(-143)
    CMD_CORDIC(32'h0, 32'h0, 32'hb0223c5b , `CMD_SINCOS, 
              32'he67193f2, 32'hecbdee6c, 32'h0 );

    // cos, sin(-142)
    CMD_CORDIC(32'h0, 32'h0, 32'hb0b13690 , `CMD_SINCOS, 
              32'he6c89dad, 32'hec4c804f, 32'h0 );

    // cos, sin(-141)
    CMD_CORDIC(32'h0, 32'h0, 32'hb14030c5 , `CMD_SINCOS, 
              32'he7219ecb, 32'hebdc9b7c, 32'h0 );

    // cos, sin(-140)
    CMD_CORDIC(32'h0, 32'h0, 32'hb1cf2afa , `CMD_SINCOS, 
              32'he77c905e, 32'heb6e48ae, 32'h0 );

    // cos, sin(-139)
    CMD_CORDIC(32'h0, 32'h0, 32'hb25e252f , `CMD_SINCOS, 
              32'he7d96b4c, 32'heb01907f, 32'h0 );

    // cos, sin(-138)
    CMD_CORDIC(32'h0, 32'h0, 32'hb2ed1f64 , `CMD_SINCOS, 
              32'he8382858, 32'hea967b6a, 32'h0 );

    // cos, sin(-137)
    CMD_CORDIC(32'h0, 32'h0, 32'hb37c199a , `CMD_SINCOS, 
              32'he898c020, 32'hea2d11c7, 32'h0 );

    // cos, sin(-136)
    CMD_CORDIC(32'h0, 32'h0, 32'hb40b13cf , `CMD_SINCOS, 
              32'he8fb2b1a, 32'he9c55bd0, 32'h0 );

    // cos, sin(-135)
    CMD_CORDIC(32'h0, 32'h0, 32'hb49a0e04 , `CMD_SINCOS, 
              32'he95f619a, 32'he95f619a, 32'h0 );

    // cos, sin(-134)
    CMD_CORDIC(32'h0, 32'h0, 32'hb5290839 , `CMD_SINCOS, 
              32'he9c55bd0, 32'he8fb2b1a, 32'h0 );

    // cos, sin(-133)
    CMD_CORDIC(32'h0, 32'h0, 32'hb5b8026e , `CMD_SINCOS, 
              32'hea2d11c7, 32'he898c020, 32'h0 );

    // cos, sin(-132)
    CMD_CORDIC(32'h0, 32'h0, 32'hb646fca3 , `CMD_SINCOS, 
              32'hea967b6a, 32'he8382858, 32'h0 );

    // cos, sin(-131)
    CMD_CORDIC(32'h0, 32'h0, 32'hb6d5f6d8 , `CMD_SINCOS, 
              32'heb01907f, 32'he7d96b4c, 32'h0 );

    // cos, sin(-130)
    CMD_CORDIC(32'h0, 32'h0, 32'hb764f10d , `CMD_SINCOS, 
              32'heb6e48ae, 32'he77c905e, 32'h0 );

    // cos, sin(-129)
    CMD_CORDIC(32'h0, 32'h0, 32'hb7f3eb42 , `CMD_SINCOS, 
              32'hebdc9b7c, 32'he7219ecb, 32'h0 );

    // cos, sin(-128)
    CMD_CORDIC(32'h0, 32'h0, 32'hb882e577 , `CMD_SINCOS, 
              32'hec4c804f, 32'he6c89dad, 32'h0 );

    // cos, sin(-127)
    CMD_CORDIC(32'h0, 32'h0, 32'hb911dfac , `CMD_SINCOS, 
              32'hecbdee6c, 32'he67193f2, 32'h0 );

    // cos, sin(-126)
    CMD_CORDIC(32'h0, 32'h0, 32'hb9a0d9e1 , `CMD_SINCOS, 
              32'hed30dcfc, 32'he61c8865, 32'h0 );

    // cos, sin(-125)
    CMD_CORDIC(32'h0, 32'h0, 32'hba2fd416 , `CMD_SINCOS, 
              32'heda54308, 32'he5c981a7, 32'h0 );

    // cos, sin(-124)
    CMD_CORDIC(32'h0, 32'h0, 32'hbabece4b , `CMD_SINCOS, 
              32'hee1b177c, 32'he5788633, 32'h0 );

    // cos, sin(-123)
    CMD_CORDIC(32'h0, 32'h0, 32'hbb4dc881 , `CMD_SINCOS, 
              32'hee925129, 32'he5299c58, 32'h0 );

    // cos, sin(-122)
    CMD_CORDIC(32'h0, 32'h0, 32'hbbdcc2b6 , `CMD_SINCOS, 
              32'hef0ae6c2, 32'he4dcca3e, 32'h0 );

    // cos, sin(-121)
    CMD_CORDIC(32'h0, 32'h0, 32'hbc6bbceb , `CMD_SINCOS, 
              32'hef84cee0, 32'he49215e2, 32'h0 );

    // cos, sin(-120)
    CMD_CORDIC(32'h0, 32'h0, 32'hbcfab720 , `CMD_SINCOS, 
              32'hf0000001, 32'he4498518, 32'h0 );

    // cos, sin(-119)
    CMD_CORDIC(32'h0, 32'h0, 32'hbd89b155 , `CMD_SINCOS, 
              32'hf07c708a, 32'he4031d89, 32'h0 );

    // cos, sin(-118)
    CMD_CORDIC(32'h0, 32'h0, 32'hbe18ab8a , `CMD_SINCOS, 
              32'hf0fa16c6, 32'he3bee4b1, 32'h0 );

    // cos, sin(-117)
    CMD_CORDIC(32'h0, 32'h0, 32'hbea7a5bf , `CMD_SINCOS, 
              32'hf178e8eb, 32'he37cdfe3, 32'h0 );

    // cos, sin(-116)
    CMD_CORDIC(32'h0, 32'h0, 32'hbf369ff4 , `CMD_SINCOS, 
              32'hf1f8dd13, 32'he33d1445, 32'h0 );

    // cos, sin(-115)
    CMD_CORDIC(32'h0, 32'h0, 32'hbfc59a29 , `CMD_SINCOS, 
              32'hf279e945, 32'he2ff86d0, 32'h0 );

    // cos, sin(-114)
    CMD_CORDIC(32'h0, 32'h0, 32'hc054945e , `CMD_SINCOS, 
              32'hf2fc0370, 32'he2c43c52, 32'h0 );

    // cos, sin(-113)
    CMD_CORDIC(32'h0, 32'h0, 32'hc0e38e93 , `CMD_SINCOS, 
              32'hf37f216f, 32'he28b3968, 32'h0 );

    // cos, sin(-112)
    CMD_CORDIC(32'h0, 32'h0, 32'hc17288c8 , `CMD_SINCOS, 
              32'hf4033909, 32'he2548287, 32'h0 );

    // cos, sin(-111)
    CMD_CORDIC(32'h0, 32'h0, 32'hc20182fd , `CMD_SINCOS, 
              32'hf4883ff1, 32'he2201bf2, 32'h0 );

    // cos, sin(-110)
    CMD_CORDIC(32'h0, 32'h0, 32'hc2907d33 , `CMD_SINCOS, 
              32'hf50e2bc6, 32'he1ee09be, 32'h0 );

    // cos, sin(-109)
    CMD_CORDIC(32'h0, 32'h0, 32'hc31f7768 , `CMD_SINCOS, 
              32'hf594f218, 32'he1be4fd5, 32'h0 );

    // cos, sin(-108)
    CMD_CORDIC(32'h0, 32'h0, 32'hc3ae719d , `CMD_SINCOS, 
              32'hf61c8865, 32'he190f1ed, 32'h0 );

    // cos, sin(-107)
    CMD_CORDIC(32'h0, 32'h0, 32'hc43d6bd2 , `CMD_SINCOS, 
              32'hf6a4e419, 32'he165f392, 32'h0 );

    // cos, sin(-106)
    CMD_CORDIC(32'h0, 32'h0, 32'hc4cc6607 , `CMD_SINCOS, 
              32'hf72dfa92, 32'he13d581d, 32'h0 );

    // cos, sin(-105)
    CMD_CORDIC(32'h0, 32'h0, 32'hc55b603c , `CMD_SINCOS, 
              32'hf7b7c120, 32'he11722b9, 32'h0 );

    // cos, sin(-104)
    CMD_CORDIC(32'h0, 32'h0, 32'hc5ea5a71 , `CMD_SINCOS, 
              32'hf8422d04, 32'he0f35661, 32'h0 );

    // cos, sin(-103)
    CMD_CORDIC(32'h0, 32'h0, 32'hc67954a6 , `CMD_SINCOS, 
              32'hf8cd3373, 32'he0d1f5df, 32'h0 );

    // cos, sin(-102)
    CMD_CORDIC(32'h0, 32'h0, 32'hc7084edb , `CMD_SINCOS, 
              32'hf958c995, 32'he0b303ce, 32'h0 );

    // cos, sin(-101)
    CMD_CORDIC(32'h0, 32'h0, 32'hc7974910 , `CMD_SINCOS, 
              32'hf9e4e489, 32'he0968297, 32'h0 );

    // cos, sin(-100)
    CMD_CORDIC(32'h0, 32'h0, 32'hc8264345 , `CMD_SINCOS, 
              32'hfa717961, 32'he07c7474, 32'h0 );

    // cos, sin(-99)
    CMD_CORDIC(32'h0, 32'h0, 32'hc8b53d7a , `CMD_SINCOS, 
              32'hfafe7d27, 32'he064db6c, 32'h0 );

    // cos, sin(-98)
    CMD_CORDIC(32'h0, 32'h0, 32'hc94437af , `CMD_SINCOS, 
              32'hfb8be4db, 32'he04fb957, 32'h0 );

    // cos, sin(-97)
    CMD_CORDIC(32'h0, 32'h0, 32'hc9d331e4 , `CMD_SINCOS, 
              32'hfc19a577, 32'he03d0fdb, 32'h0 );

    // cos, sin(-96)
    CMD_CORDIC(32'h0, 32'h0, 32'hca622c1a , `CMD_SINCOS, 
              32'hfca7b3ed, 32'he02ce06c, 32'h0 );

    // cos, sin(-95)
    CMD_CORDIC(32'h0, 32'h0, 32'hcaf1264f , `CMD_SINCOS, 
              32'hfd360529, 32'he01f2c4c, 32'h0 );

    // cos, sin(-94)
    CMD_CORDIC(32'h0, 32'h0, 32'hcb802084 , `CMD_SINCOS, 
              32'hfdc48e13, 32'he013f48f, 32'h0 );

    // cos, sin(-93)
    CMD_CORDIC(32'h0, 32'h0, 32'hcc0f1ab9 , `CMD_SINCOS, 
              32'hfe53438c, 32'he00b3a13, 32'h0 );

    // cos, sin(-92)
    CMD_CORDIC(32'h0, 32'h0, 32'hcc9e14ee , `CMD_SINCOS, 
              32'hfee21a74, 32'he004fd88, 32'h0 );

    // cos, sin(-91)
    CMD_CORDIC(32'h0, 32'h0, 32'hcd2d0f23 , `CMD_SINCOS, 
              32'hff7107a7, 32'he0013f69, 32'h0 );

    // cos, sin(-90)
    CMD_CORDIC(32'h0, 32'h0, 32'hcdbc0958 , `CMD_SINCOS, 
              32'h00000000, 32'he0000000, 32'h0 );

    // cos, sin(-89)
    CMD_CORDIC(32'h0, 32'h0, 32'hce4b038d , `CMD_SINCOS, 
              32'h008ef859, 32'he0013f69, 32'h0 );

    // cos, sin(-88)
    CMD_CORDIC(32'h0, 32'h0, 32'hced9fdc2 , `CMD_SINCOS, 
              32'h011de58c, 32'he004fd88, 32'h0 );

    // cos, sin(-87)
    CMD_CORDIC(32'h0, 32'h0, 32'hcf68f7f7 , `CMD_SINCOS, 
              32'h01acbc74, 32'he00b3a13, 32'h0 );

    // cos, sin(-86)
    CMD_CORDIC(32'h0, 32'h0, 32'hcff7f22c , `CMD_SINCOS, 
              32'h023b71ed, 32'he013f48f, 32'h0 );

    // cos, sin(-85)
    CMD_CORDIC(32'h0, 32'h0, 32'hd086ec61 , `CMD_SINCOS, 
              32'h02c9fad7, 32'he01f2c4c, 32'h0 );

    // cos, sin(-84)
    CMD_CORDIC(32'h0, 32'h0, 32'hd115e696 , `CMD_SINCOS, 
              32'h03584c13, 32'he02ce06c, 32'h0 );

    // cos, sin(-83)
    CMD_CORDIC(32'h0, 32'h0, 32'hd1a4e0cb , `CMD_SINCOS, 
              32'h03e65a89, 32'he03d0fdb, 32'h0 );

    // cos, sin(-82)
    CMD_CORDIC(32'h0, 32'h0, 32'hd233db01 , `CMD_SINCOS, 
              32'h04741b25, 32'he04fb957, 32'h0 );

    // cos, sin(-81)
    CMD_CORDIC(32'h0, 32'h0, 32'hd2c2d536 , `CMD_SINCOS, 
              32'h050182d9, 32'he064db6c, 32'h0 );

    // cos, sin(-80)
    CMD_CORDIC(32'h0, 32'h0, 32'hd351cf6b , `CMD_SINCOS, 
              32'h058e869f, 32'he07c7474, 32'h0 );

    // cos, sin(-79)
    CMD_CORDIC(32'h0, 32'h0, 32'hd3e0c9a0 , `CMD_SINCOS, 
              32'h061b1b77, 32'he0968297, 32'h0 );

    // cos, sin(-78)
    CMD_CORDIC(32'h0, 32'h0, 32'hd46fc3d5 , `CMD_SINCOS, 
              32'h06a7366b, 32'he0b303ce, 32'h0 );

    // cos, sin(-77)
    CMD_CORDIC(32'h0, 32'h0, 32'hd4febe0a , `CMD_SINCOS, 
              32'h0732cc8d, 32'he0d1f5df, 32'h0 );

    // cos, sin(-76)
    CMD_CORDIC(32'h0, 32'h0, 32'hd58db83f , `CMD_SINCOS, 
              32'h07bdd2fc, 32'he0f35661, 32'h0 );

    // cos, sin(-75)
    CMD_CORDIC(32'h0, 32'h0, 32'hd61cb274 , `CMD_SINCOS, 
              32'h08483ee0, 32'he11722b9, 32'h0 );

    // cos, sin(-74)
    CMD_CORDIC(32'h0, 32'h0, 32'hd6abaca9 , `CMD_SINCOS, 
              32'h08d2056e, 32'he13d581d, 32'h0 );

    // cos, sin(-73)
    CMD_CORDIC(32'h0, 32'h0, 32'hd73aa6de , `CMD_SINCOS, 
              32'h095b1be7, 32'he165f392, 32'h0 );

    // cos, sin(-72)
    CMD_CORDIC(32'h0, 32'h0, 32'hd7c9a113 , `CMD_SINCOS, 
              32'h09e3779b, 32'he190f1ed, 32'h0 );

    // cos, sin(-71)
    CMD_CORDIC(32'h0, 32'h0, 32'hd8589b48 , `CMD_SINCOS, 
              32'h0a6b0de8, 32'he1be4fd5, 32'h0 );

    // cos, sin(-70)
    CMD_CORDIC(32'h0, 32'h0, 32'hd8e7957d , `CMD_SINCOS, 
              32'h0af1d43a, 32'he1ee09be, 32'h0 );

    // cos, sin(-69)
    CMD_CORDIC(32'h0, 32'h0, 32'hd9768fb2 , `CMD_SINCOS, 
              32'h0b77c00f, 32'he2201bf2, 32'h0 );

    // cos, sin(-68)
    CMD_CORDIC(32'h0, 32'h0, 32'hda0589e8 , `CMD_SINCOS, 
              32'h0bfcc6f7, 32'he2548287, 32'h0 );

    // cos, sin(-67)
    CMD_CORDIC(32'h0, 32'h0, 32'hda94841d , `CMD_SINCOS, 
              32'h0c80de91, 32'he28b3968, 32'h0 );

    // cos, sin(-66)
    CMD_CORDIC(32'h0, 32'h0, 32'hdb237e52 , `CMD_SINCOS, 
              32'h0d03fc90, 32'he2c43c52, 32'h0 );

    // cos, sin(-65)
    CMD_CORDIC(32'h0, 32'h0, 32'hdbb27887 , `CMD_SINCOS, 
              32'h0d8616bb, 32'he2ff86d0, 32'h0 );

    // cos, sin(-64)
    CMD_CORDIC(32'h0, 32'h0, 32'hdc4172bc , `CMD_SINCOS, 
              32'h0e0722ed, 32'he33d1445, 32'h0 );

    // cos, sin(-63)
    CMD_CORDIC(32'h0, 32'h0, 32'hdcd06cf1 , `CMD_SINCOS, 
              32'h0e871715, 32'he37cdfe3, 32'h0 );

    // cos, sin(-62)
    CMD_CORDIC(32'h0, 32'h0, 32'hdd5f6726 , `CMD_SINCOS, 
              32'h0f05e93a, 32'he3bee4b1, 32'h0 );

    // cos, sin(-61)
    CMD_CORDIC(32'h0, 32'h0, 32'hddee615b , `CMD_SINCOS, 
              32'h0f838f76, 32'he4031d89, 32'h0 );

    // cos, sin(-60)
    CMD_CORDIC(32'h0, 32'h0, 32'hde7d5b90 , `CMD_SINCOS, 
              32'h10000000, 32'he4498518, 32'h0 );

    // cos, sin(-59)
    CMD_CORDIC(32'h0, 32'h0, 32'hdf0c55c5 , `CMD_SINCOS, 
              32'h107b3120, 32'he49215e2, 32'h0 );

    // cos, sin(-58)
    CMD_CORDIC(32'h0, 32'h0, 32'hdf9b4ffa , `CMD_SINCOS, 
              32'h10f5193e, 32'he4dcca3e, 32'h0 );

    // cos, sin(-57)
    CMD_CORDIC(32'h0, 32'h0, 32'he02a4a2f , `CMD_SINCOS, 
              32'h116daed7, 32'he5299c58, 32'h0 );

    // cos, sin(-56)
    CMD_CORDIC(32'h0, 32'h0, 32'he0b94464 , `CMD_SINCOS, 
              32'h11e4e884, 32'he5788633, 32'h0 );

    // cos, sin(-55)
    CMD_CORDIC(32'h0, 32'h0, 32'he1483e9a , `CMD_SINCOS, 
              32'h125abcf8, 32'he5c981a7, 32'h0 );

    // cos, sin(-54)
    CMD_CORDIC(32'h0, 32'h0, 32'he1d738cf , `CMD_SINCOS, 
              32'h12cf2304, 32'he61c8865, 32'h0 );

    // cos, sin(-53)
    CMD_CORDIC(32'h0, 32'h0, 32'he2663304 , `CMD_SINCOS, 
              32'h13421194, 32'he67193f2, 32'h0 );

    // cos, sin(-52)
    CMD_CORDIC(32'h0, 32'h0, 32'he2f52d39 , `CMD_SINCOS, 
              32'h13b37fb1, 32'he6c89dad, 32'h0 );

    // cos, sin(-51)
    CMD_CORDIC(32'h0, 32'h0, 32'he384276e , `CMD_SINCOS, 
              32'h14236484, 32'he7219ecb, 32'h0 );

    // cos, sin(-50)
    CMD_CORDIC(32'h0, 32'h0, 32'he41321a3 , `CMD_SINCOS, 
              32'h1491b752, 32'he77c905e, 32'h0 );

    // cos, sin(-49)
    CMD_CORDIC(32'h0, 32'h0, 32'he4a21bd8 , `CMD_SINCOS, 
              32'h14fe6f81, 32'he7d96b4c, 32'h0 );

    // cos, sin(-48)
    CMD_CORDIC(32'h0, 32'h0, 32'he531160d , `CMD_SINCOS, 
              32'h15698496, 32'he8382858, 32'h0 );

    // cos, sin(-47)
    CMD_CORDIC(32'h0, 32'h0, 32'he5c01042 , `CMD_SINCOS, 
              32'h15d2ee39, 32'he898c020, 32'h0 );

    // cos, sin(-46)
    CMD_CORDIC(32'h0, 32'h0, 32'he64f0a77 , `CMD_SINCOS, 
              32'h163aa430, 32'he8fb2b1a, 32'h0 );

    // cos, sin(-45)
    CMD_CORDIC(32'h0, 32'h0, 32'he6de04ac , `CMD_SINCOS, 
              32'h16a09e66, 32'he95f619a, 32'h0 );

    // cos, sin(-44)
    CMD_CORDIC(32'h0, 32'h0, 32'he76cfee1 , `CMD_SINCOS, 
              32'h1704d4e6, 32'he9c55bd0, 32'h0 );

    // cos, sin(-43)
    CMD_CORDIC(32'h0, 32'h0, 32'he7fbf916 , `CMD_SINCOS, 
              32'h17673fe0, 32'hea2d11c7, 32'h0 );

    // cos, sin(-42)
    CMD_CORDIC(32'h0, 32'h0, 32'he88af34b , `CMD_SINCOS, 
              32'h17c7d7a8, 32'hea967b6a, 32'h0 );

    // cos, sin(-41)
    CMD_CORDIC(32'h0, 32'h0, 32'he919ed81 , `CMD_SINCOS, 
              32'h182694b4, 32'heb01907f, 32'h0 );

    // cos, sin(-40)
    CMD_CORDIC(32'h0, 32'h0, 32'he9a8e7b6 , `CMD_SINCOS, 
              32'h18836fa2, 32'heb6e48ae, 32'h0 );

    // cos, sin(-39)
    CMD_CORDIC(32'h0, 32'h0, 32'hea37e1eb , `CMD_SINCOS, 
              32'h18de6135, 32'hebdc9b7c, 32'h0 );

    // cos, sin(-38)
    CMD_CORDIC(32'h0, 32'h0, 32'heac6dc20 , `CMD_SINCOS, 
              32'h19376253, 32'hec4c804f, 32'h0 );

    // cos, sin(-37)
    CMD_CORDIC(32'h0, 32'h0, 32'heb55d655 , `CMD_SINCOS, 
              32'h198e6c0e, 32'hecbdee6c, 32'h0 );

    // cos, sin(-36)
    CMD_CORDIC(32'h0, 32'h0, 32'hebe4d08a , `CMD_SINCOS, 
              32'h19e3779b, 32'hed30dcfc, 32'h0 );

    // cos, sin(-35)
    CMD_CORDIC(32'h0, 32'h0, 32'hec73cabf , `CMD_SINCOS, 
              32'h1a367e59, 32'heda54308, 32'h0 );

    // cos, sin(-34)
    CMD_CORDIC(32'h0, 32'h0, 32'hed02c4f4 , `CMD_SINCOS, 
              32'h1a8779cd, 32'hee1b177c, 32'h0 );

    // cos, sin(-33)
    CMD_CORDIC(32'h0, 32'h0, 32'hed91bf29 , `CMD_SINCOS, 
              32'h1ad663a8, 32'hee925129, 32'h0 );

    // cos, sin(-32)
    CMD_CORDIC(32'h0, 32'h0, 32'hee20b95e , `CMD_SINCOS, 
              32'h1b2335c2, 32'hef0ae6c2, 32'h0 );

    // cos, sin(-31)
    CMD_CORDIC(32'h0, 32'h0, 32'heeafb393 , `CMD_SINCOS, 
              32'h1b6dea1e, 32'hef84cee0, 32'h0 );

    // cos, sin(-30)
    CMD_CORDIC(32'h0, 32'h0, 32'hef3eadc8 , `CMD_SINCOS, 
              32'h1bb67ae8, 32'hf0000001, 32'h0 );

    // cos, sin(-29)
    CMD_CORDIC(32'h0, 32'h0, 32'hefcda7fd , `CMD_SINCOS, 
              32'h1bfce277, 32'hf07c708a, 32'h0 );

    // cos, sin(-28)
    CMD_CORDIC(32'h0, 32'h0, 32'hf05ca232 , `CMD_SINCOS, 
              32'h1c411b4f, 32'hf0fa16c6, 32'h0 );

    // cos, sin(-27)
    CMD_CORDIC(32'h0, 32'h0, 32'hf0eb9c68 , `CMD_SINCOS, 
              32'h1c83201d, 32'hf178e8eb, 32'h0 );

    // cos, sin(-26)
    CMD_CORDIC(32'h0, 32'h0, 32'hf17a969d , `CMD_SINCOS, 
              32'h1cc2ebbb, 32'hf1f8dd13, 32'h0 );

    // cos, sin(-25)
    CMD_CORDIC(32'h0, 32'h0, 32'hf20990d2 , `CMD_SINCOS, 
              32'h1d007930, 32'hf279e945, 32'h0 );

    // cos, sin(-24)
    CMD_CORDIC(32'h0, 32'h0, 32'hf2988b07 , `CMD_SINCOS, 
              32'h1d3bc3ae, 32'hf2fc0370, 32'h0 );

    // cos, sin(-23)
    CMD_CORDIC(32'h0, 32'h0, 32'hf327853c , `CMD_SINCOS, 
              32'h1d74c698, 32'hf37f216f, 32'h0 );

    // cos, sin(-22)
    CMD_CORDIC(32'h0, 32'h0, 32'hf3b67f71 , `CMD_SINCOS, 
              32'h1dab7d79, 32'hf4033909, 32'h0 );

    // cos, sin(-21)
    CMD_CORDIC(32'h0, 32'h0, 32'hf44579a6 , `CMD_SINCOS, 
              32'h1ddfe40e, 32'hf4883ff1, 32'h0 );

    // cos, sin(-20)
    CMD_CORDIC(32'h0, 32'h0, 32'hf4d473db , `CMD_SINCOS, 
              32'h1e11f642, 32'hf50e2bc6, 32'h0 );

    // cos, sin(-19)
    CMD_CORDIC(32'h0, 32'h0, 32'hf5636e10 , `CMD_SINCOS, 
              32'h1e41b02b, 32'hf594f218, 32'h0 );

    // cos, sin(-18)
    CMD_CORDIC(32'h0, 32'h0, 32'hf5f26845 , `CMD_SINCOS, 
              32'h1e6f0e13, 32'hf61c8865, 32'h0 );

    // cos, sin(-17)
    CMD_CORDIC(32'h0, 32'h0, 32'hf681627a , `CMD_SINCOS, 
              32'h1e9a0c6e, 32'hf6a4e419, 32'h0 );

    // cos, sin(-16)
    CMD_CORDIC(32'h0, 32'h0, 32'hf7105caf , `CMD_SINCOS, 
              32'h1ec2a7e3, 32'hf72dfa92, 32'h0 );

    // cos, sin(-15)
    CMD_CORDIC(32'h0, 32'h0, 32'hf79f56e4 , `CMD_SINCOS, 
              32'h1ee8dd47, 32'hf7b7c120, 32'h0 );

    // cos, sin(-14)
    CMD_CORDIC(32'h0, 32'h0, 32'hf82e5119 , `CMD_SINCOS, 
              32'h1f0ca99f, 32'hf8422d04, 32'h0 );

    // cos, sin(-13)
    CMD_CORDIC(32'h0, 32'h0, 32'hf8bd4b4f , `CMD_SINCOS, 
              32'h1f2e0a21, 32'hf8cd3373, 32'h0 );

    // cos, sin(-12)
    CMD_CORDIC(32'h0, 32'h0, 32'hf94c4584 , `CMD_SINCOS, 
              32'h1f4cfc32, 32'hf958c995, 32'h0 );

    // cos, sin(-11)
    CMD_CORDIC(32'h0, 32'h0, 32'hf9db3fb9 , `CMD_SINCOS, 
              32'h1f697d69, 32'hf9e4e489, 32'h0 );

    // cos, sin(-10)
    CMD_CORDIC(32'h0, 32'h0, 32'hfa6a39ee , `CMD_SINCOS, 
              32'h1f838b8c, 32'hfa717961, 32'h0 );

    // cos, sin(-9)
    CMD_CORDIC(32'h0, 32'h0, 32'hfaf93423 , `CMD_SINCOS, 
              32'h1f9b2494, 32'hfafe7d27, 32'h0 );

    // cos, sin(-8)
    CMD_CORDIC(32'h0, 32'h0, 32'hfb882e58 , `CMD_SINCOS, 
              32'h1fb046a9, 32'hfb8be4db, 32'h0 );

    // cos, sin(-7)
    CMD_CORDIC(32'h0, 32'h0, 32'hfc17288d , `CMD_SINCOS, 
              32'h1fc2f025, 32'hfc19a577, 32'h0 );

    // cos, sin(-6)
    CMD_CORDIC(32'h0, 32'h0, 32'hfca622c2 , `CMD_SINCOS, 
              32'h1fd31f94, 32'hfca7b3ed, 32'h0 );

    // cos, sin(-5)
    CMD_CORDIC(32'h0, 32'h0, 32'hfd351cf7 , `CMD_SINCOS, 
              32'h1fe0d3b4, 32'hfd360529, 32'h0 );

    // cos, sin(-4)
    CMD_CORDIC(32'h0, 32'h0, 32'hfdc4172c , `CMD_SINCOS, 
              32'h1fec0b71, 32'hfdc48e13, 32'h0 );

    // cos, sin(-3)
    CMD_CORDIC(32'h0, 32'h0, 32'hfe531161 , `CMD_SINCOS, 
              32'h1ff4c5ed, 32'hfe53438c, 32'h0 );

    // cos, sin(-2)
    CMD_CORDIC(32'h0, 32'h0, 32'hfee20b96 , `CMD_SINCOS, 
              32'h1ffb0278, 32'hfee21a74, 32'h0 );

    // cos, sin(-1)
    CMD_CORDIC(32'h0, 32'h0, 32'hff7105cb , `CMD_SINCOS, 
              32'h1ffec097, 32'hff7107a7, 32'h0 );

    // cos, sin(0)
    CMD_CORDIC(32'h0, 32'h0, 32'h00000000 , `CMD_SINCOS, 
              32'h20000000, 32'h00000000, 32'h0 );

    // cos, sin(1)
    CMD_CORDIC(32'h0, 32'h0, 32'h008efa35 , `CMD_SINCOS, 
              32'h1ffec097, 32'h008ef859, 32'h0 );

    // cos, sin(2)
    CMD_CORDIC(32'h0, 32'h0, 32'h011df46a , `CMD_SINCOS, 
              32'h1ffb0278, 32'h011de58c, 32'h0 );

    // cos, sin(3)
    CMD_CORDIC(32'h0, 32'h0, 32'h01acee9f , `CMD_SINCOS, 
              32'h1ff4c5ed, 32'h01acbc74, 32'h0 );

    // cos, sin(4)
    CMD_CORDIC(32'h0, 32'h0, 32'h023be8d4 , `CMD_SINCOS, 
              32'h1fec0b71, 32'h023b71ed, 32'h0 );

    // cos, sin(5)
    CMD_CORDIC(32'h0, 32'h0, 32'h02cae309 , `CMD_SINCOS, 
              32'h1fe0d3b4, 32'h02c9fad7, 32'h0 );

    // cos, sin(6)
    CMD_CORDIC(32'h0, 32'h0, 32'h0359dd3e , `CMD_SINCOS, 
              32'h1fd31f94, 32'h03584c13, 32'h0 );

    // cos, sin(7)
    CMD_CORDIC(32'h0, 32'h0, 32'h03e8d773 , `CMD_SINCOS, 
              32'h1fc2f025, 32'h03e65a89, 32'h0 );

    // cos, sin(8)
    CMD_CORDIC(32'h0, 32'h0, 32'h0477d1a8 , `CMD_SINCOS, 
              32'h1fb046a9, 32'h04741b25, 32'h0 );

    // cos, sin(9)
    CMD_CORDIC(32'h0, 32'h0, 32'h0506cbdd , `CMD_SINCOS, 
              32'h1f9b2494, 32'h050182d9, 32'h0 );

    // cos, sin(10)
    CMD_CORDIC(32'h0, 32'h0, 32'h0595c612 , `CMD_SINCOS, 
              32'h1f838b8c, 32'h058e869f, 32'h0 );

    // cos, sin(11)
    CMD_CORDIC(32'h0, 32'h0, 32'h0624c047 , `CMD_SINCOS, 
              32'h1f697d69, 32'h061b1b77, 32'h0 );

    // cos, sin(12)
    CMD_CORDIC(32'h0, 32'h0, 32'h06b3ba7c , `CMD_SINCOS, 
              32'h1f4cfc32, 32'h06a7366b, 32'h0 );

    // cos, sin(13)
    CMD_CORDIC(32'h0, 32'h0, 32'h0742b4b1 , `CMD_SINCOS, 
              32'h1f2e0a21, 32'h0732cc8d, 32'h0 );

    // cos, sin(14)
    CMD_CORDIC(32'h0, 32'h0, 32'h07d1aee7 , `CMD_SINCOS, 
              32'h1f0ca99f, 32'h07bdd2fc, 32'h0 );

    // cos, sin(15)
    CMD_CORDIC(32'h0, 32'h0, 32'h0860a91c , `CMD_SINCOS, 
              32'h1ee8dd47, 32'h08483ee0, 32'h0 );

    // cos, sin(16)
    CMD_CORDIC(32'h0, 32'h0, 32'h08efa351 , `CMD_SINCOS, 
              32'h1ec2a7e3, 32'h08d2056e, 32'h0 );

    // cos, sin(17)
    CMD_CORDIC(32'h0, 32'h0, 32'h097e9d86 , `CMD_SINCOS, 
              32'h1e9a0c6e, 32'h095b1be7, 32'h0 );

    // cos, sin(18)
    CMD_CORDIC(32'h0, 32'h0, 32'h0a0d97bb , `CMD_SINCOS, 
              32'h1e6f0e13, 32'h09e3779b, 32'h0 );

    // cos, sin(19)
    CMD_CORDIC(32'h0, 32'h0, 32'h0a9c91f0 , `CMD_SINCOS, 
              32'h1e41b02b, 32'h0a6b0de8, 32'h0 );

    // cos, sin(20)
    CMD_CORDIC(32'h0, 32'h0, 32'h0b2b8c25 , `CMD_SINCOS, 
              32'h1e11f642, 32'h0af1d43a, 32'h0 );

    // cos, sin(21)
    CMD_CORDIC(32'h0, 32'h0, 32'h0bba865a , `CMD_SINCOS, 
              32'h1ddfe40e, 32'h0b77c00f, 32'h0 );

    // cos, sin(22)
    CMD_CORDIC(32'h0, 32'h0, 32'h0c49808f , `CMD_SINCOS, 
              32'h1dab7d79, 32'h0bfcc6f7, 32'h0 );

    // cos, sin(23)
    CMD_CORDIC(32'h0, 32'h0, 32'h0cd87ac4 , `CMD_SINCOS, 
              32'h1d74c698, 32'h0c80de91, 32'h0 );

    // cos, sin(24)
    CMD_CORDIC(32'h0, 32'h0, 32'h0d6774f9 , `CMD_SINCOS, 
              32'h1d3bc3ae, 32'h0d03fc90, 32'h0 );

    // cos, sin(25)
    CMD_CORDIC(32'h0, 32'h0, 32'h0df66f2e , `CMD_SINCOS, 
              32'h1d007930, 32'h0d8616bb, 32'h0 );

    // cos, sin(26)
    CMD_CORDIC(32'h0, 32'h0, 32'h0e856963 , `CMD_SINCOS, 
              32'h1cc2ebbb, 32'h0e0722ed, 32'h0 );

    // cos, sin(27)
    CMD_CORDIC(32'h0, 32'h0, 32'h0f146398 , `CMD_SINCOS, 
              32'h1c83201d, 32'h0e871715, 32'h0 );

    // cos, sin(28)
    CMD_CORDIC(32'h0, 32'h0, 32'h0fa35dce , `CMD_SINCOS, 
              32'h1c411b4f, 32'h0f05e93a, 32'h0 );

    // cos, sin(29)
    CMD_CORDIC(32'h0, 32'h0, 32'h10325803 , `CMD_SINCOS, 
              32'h1bfce277, 32'h0f838f76, 32'h0 );

    // cos, sin(30)
    CMD_CORDIC(32'h0, 32'h0, 32'h10c15238 , `CMD_SINCOS, 
              32'h1bb67ae8, 32'h0fffffff, 32'h0 );

    // cos, sin(31)
    CMD_CORDIC(32'h0, 32'h0, 32'h11504c6d , `CMD_SINCOS, 
              32'h1b6dea1e, 32'h107b3120, 32'h0 );

    // cos, sin(32)
    CMD_CORDIC(32'h0, 32'h0, 32'h11df46a2 , `CMD_SINCOS, 
              32'h1b2335c2, 32'h10f5193e, 32'h0 );

    // cos, sin(33)
    CMD_CORDIC(32'h0, 32'h0, 32'h126e40d7 , `CMD_SINCOS, 
              32'h1ad663a8, 32'h116daed7, 32'h0 );

    // cos, sin(34)
    CMD_CORDIC(32'h0, 32'h0, 32'h12fd3b0c , `CMD_SINCOS, 
              32'h1a8779cd, 32'h11e4e884, 32'h0 );

    // cos, sin(35)
    CMD_CORDIC(32'h0, 32'h0, 32'h138c3541 , `CMD_SINCOS, 
              32'h1a367e59, 32'h125abcf8, 32'h0 );

    // cos, sin(36)
    CMD_CORDIC(32'h0, 32'h0, 32'h141b2f76 , `CMD_SINCOS, 
              32'h19e3779b, 32'h12cf2304, 32'h0 );

    // cos, sin(37)
    CMD_CORDIC(32'h0, 32'h0, 32'h14aa29ab , `CMD_SINCOS, 
              32'h198e6c0e, 32'h13421194, 32'h0 );

    // cos, sin(38)
    CMD_CORDIC(32'h0, 32'h0, 32'h153923e0 , `CMD_SINCOS, 
              32'h19376253, 32'h13b37fb1, 32'h0 );

    // cos, sin(39)
    CMD_CORDIC(32'h0, 32'h0, 32'h15c81e15 , `CMD_SINCOS, 
              32'h18de6135, 32'h14236484, 32'h0 );

    // cos, sin(40)
    CMD_CORDIC(32'h0, 32'h0, 32'h1657184a , `CMD_SINCOS, 
              32'h18836fa2, 32'h1491b752, 32'h0 );

    // cos, sin(41)
    CMD_CORDIC(32'h0, 32'h0, 32'h16e6127f , `CMD_SINCOS, 
              32'h182694b4, 32'h14fe6f81, 32'h0 );

    // cos, sin(42)
    CMD_CORDIC(32'h0, 32'h0, 32'h17750cb5 , `CMD_SINCOS, 
              32'h17c7d7a8, 32'h15698496, 32'h0 );

    // cos, sin(43)
    CMD_CORDIC(32'h0, 32'h0, 32'h180406ea , `CMD_SINCOS, 
              32'h17673fe0, 32'h15d2ee39, 32'h0 );

    // cos, sin(44)
    CMD_CORDIC(32'h0, 32'h0, 32'h1893011f , `CMD_SINCOS, 
              32'h1704d4e6, 32'h163aa430, 32'h0 );

    // cos, sin(45)
    CMD_CORDIC(32'h0, 32'h0, 32'h1921fb54 , `CMD_SINCOS, 
              32'h16a09e66, 32'h16a09e66, 32'h0 );

    // cos, sin(46)
    CMD_CORDIC(32'h0, 32'h0, 32'h19b0f589 , `CMD_SINCOS, 
              32'h163aa430, 32'h1704d4e6, 32'h0 );

    // cos, sin(47)
    CMD_CORDIC(32'h0, 32'h0, 32'h1a3fefbe , `CMD_SINCOS, 
              32'h15d2ee39, 32'h17673fe0, 32'h0 );

    // cos, sin(48)
    CMD_CORDIC(32'h0, 32'h0, 32'h1acee9f3 , `CMD_SINCOS, 
              32'h15698496, 32'h17c7d7a8, 32'h0 );

    // cos, sin(49)
    CMD_CORDIC(32'h0, 32'h0, 32'h1b5de428 , `CMD_SINCOS, 
              32'h14fe6f81, 32'h182694b4, 32'h0 );

    // cos, sin(50)
    CMD_CORDIC(32'h0, 32'h0, 32'h1becde5d , `CMD_SINCOS, 
              32'h1491b752, 32'h18836fa2, 32'h0 );

    // cos, sin(51)
    CMD_CORDIC(32'h0, 32'h0, 32'h1c7bd892 , `CMD_SINCOS, 
              32'h14236484, 32'h18de6135, 32'h0 );

    // cos, sin(52)
    CMD_CORDIC(32'h0, 32'h0, 32'h1d0ad2c7 , `CMD_SINCOS, 
              32'h13b37fb1, 32'h19376253, 32'h0 );

    // cos, sin(53)
    CMD_CORDIC(32'h0, 32'h0, 32'h1d99ccfc , `CMD_SINCOS, 
              32'h13421194, 32'h198e6c0e, 32'h0 );

    // cos, sin(54)
    CMD_CORDIC(32'h0, 32'h0, 32'h1e28c731 , `CMD_SINCOS, 
              32'h12cf2304, 32'h19e3779b, 32'h0 );

    // cos, sin(55)
    CMD_CORDIC(32'h0, 32'h0, 32'h1eb7c166 , `CMD_SINCOS, 
              32'h125abcf8, 32'h1a367e59, 32'h0 );

    // cos, sin(56)
    CMD_CORDIC(32'h0, 32'h0, 32'h1f46bb9c , `CMD_SINCOS, 
              32'h11e4e884, 32'h1a8779cd, 32'h0 );

    // cos, sin(57)
    CMD_CORDIC(32'h0, 32'h0, 32'h1fd5b5d1 , `CMD_SINCOS, 
              32'h116daed7, 32'h1ad663a8, 32'h0 );

    // cos, sin(58)
    CMD_CORDIC(32'h0, 32'h0, 32'h2064b006 , `CMD_SINCOS, 
              32'h10f5193e, 32'h1b2335c2, 32'h0 );

    // cos, sin(59)
    CMD_CORDIC(32'h0, 32'h0, 32'h20f3aa3b , `CMD_SINCOS, 
              32'h107b3120, 32'h1b6dea1e, 32'h0 );

    // cos, sin(60)
    CMD_CORDIC(32'h0, 32'h0, 32'h2182a470 , `CMD_SINCOS, 
              32'h10000000, 32'h1bb67ae8, 32'h0 );

    // cos, sin(61)
    CMD_CORDIC(32'h0, 32'h0, 32'h22119ea5 , `CMD_SINCOS, 
              32'h0f838f76, 32'h1bfce277, 32'h0 );

    // cos, sin(62)
    CMD_CORDIC(32'h0, 32'h0, 32'h22a098da , `CMD_SINCOS, 
              32'h0f05e93a, 32'h1c411b4f, 32'h0 );

    // cos, sin(63)
    CMD_CORDIC(32'h0, 32'h0, 32'h232f930f , `CMD_SINCOS, 
              32'h0e871715, 32'h1c83201d, 32'h0 );

    // cos, sin(64)
    CMD_CORDIC(32'h0, 32'h0, 32'h23be8d44 , `CMD_SINCOS, 
              32'h0e0722ed, 32'h1cc2ebbb, 32'h0 );

    // cos, sin(65)
    CMD_CORDIC(32'h0, 32'h0, 32'h244d8779 , `CMD_SINCOS, 
              32'h0d8616bb, 32'h1d007930, 32'h0 );

    // cos, sin(66)
    CMD_CORDIC(32'h0, 32'h0, 32'h24dc81ae , `CMD_SINCOS, 
              32'h0d03fc90, 32'h1d3bc3ae, 32'h0 );

    // cos, sin(67)
    CMD_CORDIC(32'h0, 32'h0, 32'h256b7be3 , `CMD_SINCOS, 
              32'h0c80de91, 32'h1d74c698, 32'h0 );

    // cos, sin(68)
    CMD_CORDIC(32'h0, 32'h0, 32'h25fa7618 , `CMD_SINCOS, 
              32'h0bfcc6f7, 32'h1dab7d79, 32'h0 );

    // cos, sin(69)
    CMD_CORDIC(32'h0, 32'h0, 32'h2689704e , `CMD_SINCOS, 
              32'h0b77c00f, 32'h1ddfe40e, 32'h0 );

    // cos, sin(70)
    CMD_CORDIC(32'h0, 32'h0, 32'h27186a83 , `CMD_SINCOS, 
              32'h0af1d43a, 32'h1e11f642, 32'h0 );

    // cos, sin(71)
    CMD_CORDIC(32'h0, 32'h0, 32'h27a764b8 , `CMD_SINCOS, 
              32'h0a6b0de8, 32'h1e41b02b, 32'h0 );

    // cos, sin(72)
    CMD_CORDIC(32'h0, 32'h0, 32'h28365eed , `CMD_SINCOS, 
              32'h09e3779b, 32'h1e6f0e13, 32'h0 );

    // cos, sin(73)
    CMD_CORDIC(32'h0, 32'h0, 32'h28c55922 , `CMD_SINCOS, 
              32'h095b1be7, 32'h1e9a0c6e, 32'h0 );

    // cos, sin(74)
    CMD_CORDIC(32'h0, 32'h0, 32'h29545357 , `CMD_SINCOS, 
              32'h08d2056e, 32'h1ec2a7e3, 32'h0 );

    // cos, sin(75)
    CMD_CORDIC(32'h0, 32'h0, 32'h29e34d8c , `CMD_SINCOS, 
              32'h08483ee0, 32'h1ee8dd47, 32'h0 );

    // cos, sin(76)
    CMD_CORDIC(32'h0, 32'h0, 32'h2a7247c1 , `CMD_SINCOS, 
              32'h07bdd2fc, 32'h1f0ca99f, 32'h0 );

    // cos, sin(77)
    CMD_CORDIC(32'h0, 32'h0, 32'h2b0141f6 , `CMD_SINCOS, 
              32'h0732cc8d, 32'h1f2e0a21, 32'h0 );

    // cos, sin(78)
    CMD_CORDIC(32'h0, 32'h0, 32'h2b903c2b , `CMD_SINCOS, 
              32'h06a7366b, 32'h1f4cfc32, 32'h0 );

    // cos, sin(79)
    CMD_CORDIC(32'h0, 32'h0, 32'h2c1f3660 , `CMD_SINCOS, 
              32'h061b1b77, 32'h1f697d69, 32'h0 );

    // cos, sin(80)
    CMD_CORDIC(32'h0, 32'h0, 32'h2cae3095 , `CMD_SINCOS, 
              32'h058e869f, 32'h1f838b8c, 32'h0 );

    // cos, sin(81)
    CMD_CORDIC(32'h0, 32'h0, 32'h2d3d2aca , `CMD_SINCOS, 
              32'h050182d9, 32'h1f9b2494, 32'h0 );

    // cos, sin(82)
    CMD_CORDIC(32'h0, 32'h0, 32'h2dcc24ff , `CMD_SINCOS, 
              32'h04741b25, 32'h1fb046a9, 32'h0 );

    // cos, sin(83)
    CMD_CORDIC(32'h0, 32'h0, 32'h2e5b1f35 , `CMD_SINCOS, 
              32'h03e65a89, 32'h1fc2f025, 32'h0 );

    // cos, sin(84)
    CMD_CORDIC(32'h0, 32'h0, 32'h2eea196a , `CMD_SINCOS, 
              32'h03584c13, 32'h1fd31f94, 32'h0 );

    // cos, sin(85)
    CMD_CORDIC(32'h0, 32'h0, 32'h2f79139f , `CMD_SINCOS, 
              32'h02c9fad7, 32'h1fe0d3b4, 32'h0 );

    // cos, sin(86)
    CMD_CORDIC(32'h0, 32'h0, 32'h30080dd4 , `CMD_SINCOS, 
              32'h023b71ed, 32'h1fec0b71, 32'h0 );

    // cos, sin(87)
    CMD_CORDIC(32'h0, 32'h0, 32'h30970809 , `CMD_SINCOS, 
              32'h01acbc74, 32'h1ff4c5ed, 32'h0 );

    // cos, sin(88)
    CMD_CORDIC(32'h0, 32'h0, 32'h3126023e , `CMD_SINCOS, 
              32'h011de58c, 32'h1ffb0278, 32'h0 );

    // cos, sin(89)
    CMD_CORDIC(32'h0, 32'h0, 32'h31b4fc73 , `CMD_SINCOS, 
              32'h008ef859, 32'h1ffec097, 32'h0 );

    // cos, sin(90)
    CMD_CORDIC(32'h0, 32'h0, 32'h3243f6a8 , `CMD_SINCOS, 
              32'h00000000, 32'h20000000, 32'h0 );

    // cos, sin(91)
    CMD_CORDIC(32'h0, 32'h0, 32'h32d2f0dd , `CMD_SINCOS, 
              32'hff7107a7, 32'h1ffec097, 32'h0 );

    // cos, sin(92)
    CMD_CORDIC(32'h0, 32'h0, 32'h3361eb12 , `CMD_SINCOS, 
              32'hfee21a74, 32'h1ffb0278, 32'h0 );

    // cos, sin(93)
    CMD_CORDIC(32'h0, 32'h0, 32'h33f0e547 , `CMD_SINCOS, 
              32'hfe53438c, 32'h1ff4c5ed, 32'h0 );

    // cos, sin(94)
    CMD_CORDIC(32'h0, 32'h0, 32'h347fdf7c , `CMD_SINCOS, 
              32'hfdc48e13, 32'h1fec0b71, 32'h0 );

    // cos, sin(95)
    CMD_CORDIC(32'h0, 32'h0, 32'h350ed9b1 , `CMD_SINCOS, 
              32'hfd360529, 32'h1fe0d3b4, 32'h0 );

    // cos, sin(96)
    CMD_CORDIC(32'h0, 32'h0, 32'h359dd3e6 , `CMD_SINCOS, 
              32'hfca7b3ed, 32'h1fd31f94, 32'h0 );

    // cos, sin(97)
    CMD_CORDIC(32'h0, 32'h0, 32'h362cce1c , `CMD_SINCOS, 
              32'hfc19a577, 32'h1fc2f025, 32'h0 );

    // cos, sin(98)
    CMD_CORDIC(32'h0, 32'h0, 32'h36bbc851 , `CMD_SINCOS, 
              32'hfb8be4db, 32'h1fb046a9, 32'h0 );

    // cos, sin(99)
    CMD_CORDIC(32'h0, 32'h0, 32'h374ac286 , `CMD_SINCOS, 
              32'hfafe7d27, 32'h1f9b2494, 32'h0 );

    // cos, sin(100)
    CMD_CORDIC(32'h0, 32'h0, 32'h37d9bcbb , `CMD_SINCOS, 
              32'hfa717961, 32'h1f838b8c, 32'h0 );

    // cos, sin(101)
    CMD_CORDIC(32'h0, 32'h0, 32'h3868b6f0 , `CMD_SINCOS, 
              32'hf9e4e489, 32'h1f697d69, 32'h0 );

    // cos, sin(102)
    CMD_CORDIC(32'h0, 32'h0, 32'h38f7b125 , `CMD_SINCOS, 
              32'hf958c995, 32'h1f4cfc32, 32'h0 );

    // cos, sin(103)
    CMD_CORDIC(32'h0, 32'h0, 32'h3986ab5a , `CMD_SINCOS, 
              32'hf8cd3373, 32'h1f2e0a21, 32'h0 );

    // cos, sin(104)
    CMD_CORDIC(32'h0, 32'h0, 32'h3a15a58f , `CMD_SINCOS, 
              32'hf8422d04, 32'h1f0ca99f, 32'h0 );

    // cos, sin(105)
    CMD_CORDIC(32'h0, 32'h0, 32'h3aa49fc4 , `CMD_SINCOS, 
              32'hf7b7c120, 32'h1ee8dd47, 32'h0 );

    // cos, sin(106)
    CMD_CORDIC(32'h0, 32'h0, 32'h3b3399f9 , `CMD_SINCOS, 
              32'hf72dfa92, 32'h1ec2a7e3, 32'h0 );

    // cos, sin(107)
    CMD_CORDIC(32'h0, 32'h0, 32'h3bc2942e , `CMD_SINCOS, 
              32'hf6a4e419, 32'h1e9a0c6e, 32'h0 );

    // cos, sin(108)
    CMD_CORDIC(32'h0, 32'h0, 32'h3c518e63 , `CMD_SINCOS, 
              32'hf61c8865, 32'h1e6f0e13, 32'h0 );

    // cos, sin(109)
    CMD_CORDIC(32'h0, 32'h0, 32'h3ce08898 , `CMD_SINCOS, 
              32'hf594f218, 32'h1e41b02b, 32'h0 );

    // cos, sin(110)
    CMD_CORDIC(32'h0, 32'h0, 32'h3d6f82cd , `CMD_SINCOS, 
              32'hf50e2bc6, 32'h1e11f642, 32'h0 );

    // cos, sin(111)
    CMD_CORDIC(32'h0, 32'h0, 32'h3dfe7d03 , `CMD_SINCOS, 
              32'hf4883ff1, 32'h1ddfe40e, 32'h0 );

    // cos, sin(112)
    CMD_CORDIC(32'h0, 32'h0, 32'h3e8d7738 , `CMD_SINCOS, 
              32'hf4033909, 32'h1dab7d79, 32'h0 );

    // cos, sin(113)
    CMD_CORDIC(32'h0, 32'h0, 32'h3f1c716d , `CMD_SINCOS, 
              32'hf37f216f, 32'h1d74c698, 32'h0 );

    // cos, sin(114)
    CMD_CORDIC(32'h0, 32'h0, 32'h3fab6ba2 , `CMD_SINCOS, 
              32'hf2fc0370, 32'h1d3bc3ae, 32'h0 );

    // cos, sin(115)
    CMD_CORDIC(32'h0, 32'h0, 32'h403a65d7 , `CMD_SINCOS, 
              32'hf279e945, 32'h1d007930, 32'h0 );

    // cos, sin(116)
    CMD_CORDIC(32'h0, 32'h0, 32'h40c9600c , `CMD_SINCOS, 
              32'hf1f8dd13, 32'h1cc2ebbb, 32'h0 );

    // cos, sin(117)
    CMD_CORDIC(32'h0, 32'h0, 32'h41585a41 , `CMD_SINCOS, 
              32'hf178e8eb, 32'h1c83201d, 32'h0 );

    // cos, sin(118)
    CMD_CORDIC(32'h0, 32'h0, 32'h41e75476 , `CMD_SINCOS, 
              32'hf0fa16c6, 32'h1c411b4f, 32'h0 );

    // cos, sin(119)
    CMD_CORDIC(32'h0, 32'h0, 32'h42764eab , `CMD_SINCOS, 
              32'hf07c708a, 32'h1bfce277, 32'h0 );

    // cos, sin(120)
    CMD_CORDIC(32'h0, 32'h0, 32'h430548e0 , `CMD_SINCOS, 
              32'hf0000001, 32'h1bb67ae8, 32'h0 );

    // cos, sin(121)
    CMD_CORDIC(32'h0, 32'h0, 32'h43944315 , `CMD_SINCOS, 
              32'hef84cee0, 32'h1b6dea1e, 32'h0 );

    // cos, sin(122)
    CMD_CORDIC(32'h0, 32'h0, 32'h44233d4a , `CMD_SINCOS, 
              32'hef0ae6c2, 32'h1b2335c2, 32'h0 );

    // cos, sin(123)
    CMD_CORDIC(32'h0, 32'h0, 32'h44b2377f , `CMD_SINCOS, 
              32'hee925129, 32'h1ad663a8, 32'h0 );

    // cos, sin(124)
    CMD_CORDIC(32'h0, 32'h0, 32'h454131b5 , `CMD_SINCOS, 
              32'hee1b177c, 32'h1a8779cd, 32'h0 );

    // cos, sin(125)
    CMD_CORDIC(32'h0, 32'h0, 32'h45d02bea , `CMD_SINCOS, 
              32'heda54308, 32'h1a367e59, 32'h0 );

    // cos, sin(126)
    CMD_CORDIC(32'h0, 32'h0, 32'h465f261f , `CMD_SINCOS, 
              32'hed30dcfc, 32'h19e3779b, 32'h0 );

    // cos, sin(127)
    CMD_CORDIC(32'h0, 32'h0, 32'h46ee2054 , `CMD_SINCOS, 
              32'hecbdee6c, 32'h198e6c0e, 32'h0 );

    // cos, sin(128)
    CMD_CORDIC(32'h0, 32'h0, 32'h477d1a89 , `CMD_SINCOS, 
              32'hec4c804f, 32'h19376253, 32'h0 );

    // cos, sin(129)
    CMD_CORDIC(32'h0, 32'h0, 32'h480c14be , `CMD_SINCOS, 
              32'hebdc9b7c, 32'h18de6135, 32'h0 );

    // cos, sin(130)
    CMD_CORDIC(32'h0, 32'h0, 32'h489b0ef3 , `CMD_SINCOS, 
              32'heb6e48ae, 32'h18836fa2, 32'h0 );

    // cos, sin(131)
    CMD_CORDIC(32'h0, 32'h0, 32'h492a0928 , `CMD_SINCOS, 
              32'heb01907f, 32'h182694b4, 32'h0 );

    // cos, sin(132)
    CMD_CORDIC(32'h0, 32'h0, 32'h49b9035d , `CMD_SINCOS, 
              32'hea967b6a, 32'h17c7d7a8, 32'h0 );

    // cos, sin(133)
    CMD_CORDIC(32'h0, 32'h0, 32'h4a47fd92 , `CMD_SINCOS, 
              32'hea2d11c7, 32'h17673fe0, 32'h0 );

    // cos, sin(134)
    CMD_CORDIC(32'h0, 32'h0, 32'h4ad6f7c7 , `CMD_SINCOS, 
              32'he9c55bd0, 32'h1704d4e6, 32'h0 );

    // cos, sin(135)
    CMD_CORDIC(32'h0, 32'h0, 32'h4b65f1fc , `CMD_SINCOS, 
              32'he95f619a, 32'h16a09e66, 32'h0 );

    // cos, sin(136)
    CMD_CORDIC(32'h0, 32'h0, 32'h4bf4ec31 , `CMD_SINCOS, 
              32'he8fb2b1a, 32'h163aa430, 32'h0 );

    // cos, sin(137)
    CMD_CORDIC(32'h0, 32'h0, 32'h4c83e666 , `CMD_SINCOS, 
              32'he898c020, 32'h15d2ee39, 32'h0 );

    // cos, sin(138)
    CMD_CORDIC(32'h0, 32'h0, 32'h4d12e09c , `CMD_SINCOS, 
              32'he8382858, 32'h15698496, 32'h0 );

    // cos, sin(139)
    CMD_CORDIC(32'h0, 32'h0, 32'h4da1dad1 , `CMD_SINCOS, 
              32'he7d96b4c, 32'h14fe6f81, 32'h0 );

    // cos, sin(140)
    CMD_CORDIC(32'h0, 32'h0, 32'h4e30d506 , `CMD_SINCOS, 
              32'he77c905e, 32'h1491b752, 32'h0 );

    // cos, sin(141)
    CMD_CORDIC(32'h0, 32'h0, 32'h4ebfcf3b , `CMD_SINCOS, 
              32'he7219ecb, 32'h14236484, 32'h0 );

    // cos, sin(142)
    CMD_CORDIC(32'h0, 32'h0, 32'h4f4ec970 , `CMD_SINCOS, 
              32'he6c89dad, 32'h13b37fb1, 32'h0 );

    // cos, sin(143)
    CMD_CORDIC(32'h0, 32'h0, 32'h4fddc3a5 , `CMD_SINCOS, 
              32'he67193f2, 32'h13421194, 32'h0 );

    // cos, sin(144)
    CMD_CORDIC(32'h0, 32'h0, 32'h506cbdda , `CMD_SINCOS, 
              32'he61c8865, 32'h12cf2304, 32'h0 );

    // cos, sin(145)
    CMD_CORDIC(32'h0, 32'h0, 32'h50fbb80f , `CMD_SINCOS, 
              32'he5c981a7, 32'h125abcf8, 32'h0 );

    // cos, sin(146)
    CMD_CORDIC(32'h0, 32'h0, 32'h518ab244 , `CMD_SINCOS, 
              32'he5788633, 32'h11e4e884, 32'h0 );

    // cos, sin(147)
    CMD_CORDIC(32'h0, 32'h0, 32'h5219ac79 , `CMD_SINCOS, 
              32'he5299c58, 32'h116daed7, 32'h0 );

    // cos, sin(148)
    CMD_CORDIC(32'h0, 32'h0, 32'h52a8a6ae , `CMD_SINCOS, 
              32'he4dcca3e, 32'h10f5193e, 32'h0 );

    // cos, sin(149)
    CMD_CORDIC(32'h0, 32'h0, 32'h5337a0e3 , `CMD_SINCOS, 
              32'he49215e2, 32'h107b3120, 32'h0 );

    // cos, sin(150)
    CMD_CORDIC(32'h0, 32'h0, 32'h53c69b18 , `CMD_SINCOS, 
              32'he4498518, 32'h0fffffff, 32'h0 );

    // cos, sin(151)
    CMD_CORDIC(32'h0, 32'h0, 32'h5455954d , `CMD_SINCOS, 
              32'he4031d89, 32'h0f838f76, 32'h0 );

    // cos, sin(152)
    CMD_CORDIC(32'h0, 32'h0, 32'h54e48f83 , `CMD_SINCOS, 
              32'he3bee4b1, 32'h0f05e93a, 32'h0 );

    // cos, sin(153)
    CMD_CORDIC(32'h0, 32'h0, 32'h557389b8 , `CMD_SINCOS, 
              32'he37cdfe3, 32'h0e871715, 32'h0 );

    // cos, sin(154)
    CMD_CORDIC(32'h0, 32'h0, 32'h560283ed , `CMD_SINCOS, 
              32'he33d1445, 32'h0e0722ed, 32'h0 );

    // cos, sin(155)
    CMD_CORDIC(32'h0, 32'h0, 32'h56917e22 , `CMD_SINCOS, 
              32'he2ff86d0, 32'h0d8616bb, 32'h0 );

    // cos, sin(156)
    CMD_CORDIC(32'h0, 32'h0, 32'h57207857 , `CMD_SINCOS, 
              32'he2c43c52, 32'h0d03fc90, 32'h0 );

    // cos, sin(157)
    CMD_CORDIC(32'h0, 32'h0, 32'h57af728c , `CMD_SINCOS, 
              32'he28b3968, 32'h0c80de91, 32'h0 );

    // cos, sin(158)
    CMD_CORDIC(32'h0, 32'h0, 32'h583e6cc1 , `CMD_SINCOS, 
              32'he2548287, 32'h0bfcc6f7, 32'h0 );

    // cos, sin(159)
    CMD_CORDIC(32'h0, 32'h0, 32'h58cd66f6 , `CMD_SINCOS, 
              32'he2201bf2, 32'h0b77c00f, 32'h0 );

    // cos, sin(160)
    CMD_CORDIC(32'h0, 32'h0, 32'h595c612b , `CMD_SINCOS, 
              32'he1ee09be, 32'h0af1d43a, 32'h0 );

    // cos, sin(161)
    CMD_CORDIC(32'h0, 32'h0, 32'h59eb5b60 , `CMD_SINCOS, 
              32'he1be4fd5, 32'h0a6b0de8, 32'h0 );

    // cos, sin(162)
    CMD_CORDIC(32'h0, 32'h0, 32'h5a7a5595 , `CMD_SINCOS, 
              32'he190f1ed, 32'h09e3779b, 32'h0 );

    // cos, sin(163)
    CMD_CORDIC(32'h0, 32'h0, 32'h5b094fca , `CMD_SINCOS, 
              32'he165f392, 32'h095b1be7, 32'h0 );

    // cos, sin(164)
    CMD_CORDIC(32'h0, 32'h0, 32'h5b9849ff , `CMD_SINCOS, 
              32'he13d581d, 32'h08d2056e, 32'h0 );

    // cos, sin(165)
    CMD_CORDIC(32'h0, 32'h0, 32'h5c274434 , `CMD_SINCOS, 
              32'he11722b9, 32'h08483ee0, 32'h0 );

    // cos, sin(166)
    CMD_CORDIC(32'h0, 32'h0, 32'h5cb63e6a , `CMD_SINCOS, 
              32'he0f35661, 32'h07bdd2fc, 32'h0 );

    // cos, sin(167)
    CMD_CORDIC(32'h0, 32'h0, 32'h5d45389f , `CMD_SINCOS, 
              32'he0d1f5df, 32'h0732cc8d, 32'h0 );

    // cos, sin(168)
    CMD_CORDIC(32'h0, 32'h0, 32'h5dd432d4 , `CMD_SINCOS, 
              32'he0b303ce, 32'h06a7366b, 32'h0 );

    // cos, sin(169)
    CMD_CORDIC(32'h0, 32'h0, 32'h5e632d09 , `CMD_SINCOS, 
              32'he0968297, 32'h061b1b77, 32'h0 );

    // cos, sin(170)
    CMD_CORDIC(32'h0, 32'h0, 32'h5ef2273e , `CMD_SINCOS, 
              32'he07c7474, 32'h058e869f, 32'h0 );

    // cos, sin(171)
    CMD_CORDIC(32'h0, 32'h0, 32'h5f812173 , `CMD_SINCOS, 
              32'he064db6c, 32'h050182d9, 32'h0 );

    // cos, sin(172)
    CMD_CORDIC(32'h0, 32'h0, 32'h60101ba8 , `CMD_SINCOS, 
              32'he04fb957, 32'h04741b25, 32'h0 );

    // cos, sin(173)
    CMD_CORDIC(32'h0, 32'h0, 32'h609f15dd , `CMD_SINCOS, 
              32'he03d0fdb, 32'h03e65a89, 32'h0 );

    // cos, sin(174)
    CMD_CORDIC(32'h0, 32'h0, 32'h612e1012 , `CMD_SINCOS, 
              32'he02ce06c, 32'h03584c13, 32'h0 );

    // cos, sin(175)
    CMD_CORDIC(32'h0, 32'h0, 32'h61bd0a47 , `CMD_SINCOS, 
              32'he01f2c4c, 32'h02c9fad7, 32'h0 );

    // cos, sin(176)
    CMD_CORDIC(32'h0, 32'h0, 32'h624c047c , `CMD_SINCOS, 
              32'he013f48f, 32'h023b71ed, 32'h0 );

    // cos, sin(177)
    CMD_CORDIC(32'h0, 32'h0, 32'h62dafeb1 , `CMD_SINCOS, 
              32'he00b3a13, 32'h01acbc74, 32'h0 );

    // cos, sin(178)
    CMD_CORDIC(32'h0, 32'h0, 32'h6369f8e6 , `CMD_SINCOS, 
              32'he004fd88, 32'h011de58c, 32'h0 );

    // cos, sin(179)
    CMD_CORDIC(32'h0, 32'h0, 32'h63f8f31b , `CMD_SINCOS, 
              32'he0013f69, 32'h008ef859, 32'h0 );

    // cos, sin(180)
    CMD_CORDIC(32'h0, 32'h0, 32'h6487ed51 , `CMD_SINCOS, 
              32'he0000000, 32'h00000000, 32'h0 );

    // atan (-180)
    CMD_CORDIC(32'he0000000, 32'h00000000, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9b7812af );

    // atan (-179)
    CMD_CORDIC(32'he0013f69, 32'hff7107a7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9c070ce5 );

    // atan (-178)
    CMD_CORDIC(32'he004fd88, 32'hfee21a74, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9c96071a );

    // atan (-177)
    CMD_CORDIC(32'he00b3a13, 32'hfe53438c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9d25014f );

    // atan (-176)
    CMD_CORDIC(32'he013f48f, 32'hfdc48e13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9db3fb84 );

    // atan (-175)
    CMD_CORDIC(32'he01f2c4c, 32'hfd360529, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9e42f5b9 );

    // atan (-174)
    CMD_CORDIC(32'he02ce06c, 32'hfca7b3ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9ed1efee );

    // atan (-173)
    CMD_CORDIC(32'he03d0fdb, 32'hfc19a577, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9f60ea23 );

    // atan (-172)
    CMD_CORDIC(32'he04fb957, 32'hfb8be4db, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h9fefe458 );

    // atan (-171)
    CMD_CORDIC(32'he064db6c, 32'hfafe7d27, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha07ede8d );

    // atan (-170)
    CMD_CORDIC(32'he07c7474, 32'hfa717961, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha10dd8c2 );

    // atan (-169)
    CMD_CORDIC(32'he0968297, 32'hf9e4e489, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha19cd2f7 );

    // atan (-168)
    CMD_CORDIC(32'he0b303ce, 32'hf958c995, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha22bcd2c );

    // atan (-167)
    CMD_CORDIC(32'he0d1f5df, 32'hf8cd3373, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha2bac761 );

    // atan (-166)
    CMD_CORDIC(32'he0f35661, 32'hf8422d04, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha349c196 );

    // atan (-165)
    CMD_CORDIC(32'he11722b9, 32'hf7b7c120, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha3d8bbcc );

    // atan (-164)
    CMD_CORDIC(32'he13d581d, 32'hf72dfa92, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha467b601 );

    // atan (-163)
    CMD_CORDIC(32'he165f392, 32'hf6a4e419, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha4f6b036 );

    // atan (-162)
    CMD_CORDIC(32'he190f1ed, 32'hf61c8865, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha585aa6b );

    // atan (-161)
    CMD_CORDIC(32'he1be4fd5, 32'hf594f218, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha614a4a0 );

    // atan (-160)
    CMD_CORDIC(32'he1ee09be, 32'hf50e2bc6, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha6a39ed5 );

    // atan (-159)
    CMD_CORDIC(32'he2201bf2, 32'hf4883ff1, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha732990a );

    // atan (-158)
    CMD_CORDIC(32'he2548287, 32'hf4033909, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha7c1933f );

    // atan (-157)
    CMD_CORDIC(32'he28b3968, 32'hf37f216f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha8508d74 );

    // atan (-156)
    CMD_CORDIC(32'he2c43c52, 32'hf2fc0370, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha8df87a9 );

    // atan (-155)
    CMD_CORDIC(32'he2ff86d0, 32'hf279e945, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha96e81de );

    // atan (-154)
    CMD_CORDIC(32'he33d1445, 32'hf1f8dd13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'ha9fd7c13 );

    // atan (-153)
    CMD_CORDIC(32'he37cdfe3, 32'hf178e8eb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'haa8c7648 );

    // atan (-152)
    CMD_CORDIC(32'he3bee4b1, 32'hf0fa16c6, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hab1b707d );

    // atan (-151)
    CMD_CORDIC(32'he4031d89, 32'hf07c708a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'habaa6ab3 );

    // atan (-150)
    CMD_CORDIC(32'he4498518, 32'hf0000001, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hac3964e8 );

    // atan (-149)
    CMD_CORDIC(32'he49215e2, 32'hef84cee0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hacc85f1d );

    // atan (-148)
    CMD_CORDIC(32'he4dcca3e, 32'hef0ae6c2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'had575952 );

    // atan (-147)
    CMD_CORDIC(32'he5299c58, 32'hee925129, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hade65387 );

    // atan (-146)
    CMD_CORDIC(32'he5788633, 32'hee1b177c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hae754dbc );

    // atan (-145)
    CMD_CORDIC(32'he5c981a7, 32'heda54308, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'haf0447f1 );

    // atan (-144)
    CMD_CORDIC(32'he61c8865, 32'hed30dcfc, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'haf934226 );

    // atan (-143)
    CMD_CORDIC(32'he67193f2, 32'hecbdee6c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb0223c5b );

    // atan (-142)
    CMD_CORDIC(32'he6c89dad, 32'hec4c804f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb0b13690 );

    // atan (-141)
    CMD_CORDIC(32'he7219ecb, 32'hebdc9b7c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb14030c5 );

    // atan (-140)
    CMD_CORDIC(32'he77c905e, 32'heb6e48ae, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb1cf2afa );

    // atan (-139)
    CMD_CORDIC(32'he7d96b4c, 32'heb01907f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb25e252f );

    // atan (-138)
    CMD_CORDIC(32'he8382858, 32'hea967b6a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb2ed1f64 );

    // atan (-137)
    CMD_CORDIC(32'he898c020, 32'hea2d11c7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb37c199a );

    // atan (-136)
    CMD_CORDIC(32'he8fb2b1a, 32'he9c55bd0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb40b13cf );

    // atan (-135)
    CMD_CORDIC(32'he95f619a, 32'he95f619a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb49a0e04 );

    // atan (-134)
    CMD_CORDIC(32'he9c55bd0, 32'he8fb2b1a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb5290839 );

    // atan (-133)
    CMD_CORDIC(32'hea2d11c7, 32'he898c020, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb5b8026e );

    // atan (-132)
    CMD_CORDIC(32'hea967b6a, 32'he8382858, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb646fca3 );

    // atan (-131)
    CMD_CORDIC(32'heb01907f, 32'he7d96b4c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb6d5f6d8 );

    // atan (-130)
    CMD_CORDIC(32'heb6e48ae, 32'he77c905e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb764f10d );

    // atan (-129)
    CMD_CORDIC(32'hebdc9b7c, 32'he7219ecb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb7f3eb42 );

    // atan (-128)
    CMD_CORDIC(32'hec4c804f, 32'he6c89dad, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb882e577 );

    // atan (-127)
    CMD_CORDIC(32'hecbdee6c, 32'he67193f2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb911dfac );

    // atan (-126)
    CMD_CORDIC(32'hed30dcfc, 32'he61c8865, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hb9a0d9e1 );

    // atan (-125)
    CMD_CORDIC(32'heda54308, 32'he5c981a7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hba2fd416 );

    // atan (-124)
    CMD_CORDIC(32'hee1b177c, 32'he5788633, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbabece4b );

    // atan (-123)
    CMD_CORDIC(32'hee925129, 32'he5299c58, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbb4dc881 );

    // atan (-122)
    CMD_CORDIC(32'hef0ae6c2, 32'he4dcca3e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbbdcc2b6 );

    // atan (-121)
    CMD_CORDIC(32'hef84cee0, 32'he49215e2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbc6bbceb );

    // atan (-120)
    CMD_CORDIC(32'hf0000001, 32'he4498518, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbcfab720 );

    // atan (-119)
    CMD_CORDIC(32'hf07c708a, 32'he4031d89, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbd89b155 );

    // atan (-118)
    CMD_CORDIC(32'hf0fa16c6, 32'he3bee4b1, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbe18ab8a );

    // atan (-117)
    CMD_CORDIC(32'hf178e8eb, 32'he37cdfe3, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbea7a5bf );

    // atan (-116)
    CMD_CORDIC(32'hf1f8dd13, 32'he33d1445, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbf369ff4 );

    // atan (-115)
    CMD_CORDIC(32'hf279e945, 32'he2ff86d0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hbfc59a29 );

    // atan (-114)
    CMD_CORDIC(32'hf2fc0370, 32'he2c43c52, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc054945e );

    // atan (-113)
    CMD_CORDIC(32'hf37f216f, 32'he28b3968, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc0e38e93 );

    // atan (-112)
    CMD_CORDIC(32'hf4033909, 32'he2548287, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc17288c8 );

    // atan (-111)
    CMD_CORDIC(32'hf4883ff1, 32'he2201bf2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc20182fd );

    // atan (-110)
    CMD_CORDIC(32'hf50e2bc6, 32'he1ee09be, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc2907d33 );

    // atan (-109)
    CMD_CORDIC(32'hf594f218, 32'he1be4fd5, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc31f7768 );

    // atan (-108)
    CMD_CORDIC(32'hf61c8865, 32'he190f1ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc3ae719d );

    // atan (-107)
    CMD_CORDIC(32'hf6a4e419, 32'he165f392, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc43d6bd2 );

    // atan (-106)
    CMD_CORDIC(32'hf72dfa92, 32'he13d581d, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc4cc6607 );

    // atan (-105)
    CMD_CORDIC(32'hf7b7c120, 32'he11722b9, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc55b603c );

    // atan (-104)
    CMD_CORDIC(32'hf8422d04, 32'he0f35661, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc5ea5a71 );

    // atan (-103)
    CMD_CORDIC(32'hf8cd3373, 32'he0d1f5df, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc67954a6 );

    // atan (-102)
    CMD_CORDIC(32'hf958c995, 32'he0b303ce, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc7084edb );

    // atan (-101)
    CMD_CORDIC(32'hf9e4e489, 32'he0968297, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc7974910 );

    // atan (-100)
    CMD_CORDIC(32'hfa717961, 32'he07c7474, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc8264345 );

    // atan (-99)
    CMD_CORDIC(32'hfafe7d27, 32'he064db6c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc8b53d7a );

    // atan (-98)
    CMD_CORDIC(32'hfb8be4db, 32'he04fb957, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc94437af );

    // atan (-97)
    CMD_CORDIC(32'hfc19a577, 32'he03d0fdb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hc9d331e4 );

    // atan (-96)
    CMD_CORDIC(32'hfca7b3ed, 32'he02ce06c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hca622c1a );

    // atan (-95)
    CMD_CORDIC(32'hfd360529, 32'he01f2c4c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hcaf1264f );

    // atan (-94)
    CMD_CORDIC(32'hfdc48e13, 32'he013f48f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hcb802084 );

    // atan (-93)
    CMD_CORDIC(32'hfe53438c, 32'he00b3a13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hcc0f1ab9 );

    // atan (-92)
    CMD_CORDIC(32'hfee21a74, 32'he004fd88, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hcc9e14ee );

    // atan (-91)
    CMD_CORDIC(32'hff7107a7, 32'he0013f69, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hcd2d0f23 );

    // atan (-90)
    CMD_CORDIC(32'h00000000, 32'he0000000, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hcdbc0958 );

    // atan (-89)
    CMD_CORDIC(32'h008ef859, 32'he0013f69, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hce4b038d );

    // atan (-88)
    CMD_CORDIC(32'h011de58c, 32'he004fd88, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hced9fdc2 );

    // atan (-87)
    CMD_CORDIC(32'h01acbc74, 32'he00b3a13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hcf68f7f7 );

    // atan (-86)
    CMD_CORDIC(32'h023b71ed, 32'he013f48f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hcff7f22c );

    // atan (-85)
    CMD_CORDIC(32'h02c9fad7, 32'he01f2c4c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd086ec61 );

    // atan (-84)
    CMD_CORDIC(32'h03584c13, 32'he02ce06c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd115e696 );

    // atan (-83)
    CMD_CORDIC(32'h03e65a89, 32'he03d0fdb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd1a4e0cb );

    // atan (-82)
    CMD_CORDIC(32'h04741b25, 32'he04fb957, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd233db01 );

    // atan (-81)
    CMD_CORDIC(32'h050182d9, 32'he064db6c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd2c2d536 );

    // atan (-80)
    CMD_CORDIC(32'h058e869f, 32'he07c7474, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd351cf6b );

    // atan (-79)
    CMD_CORDIC(32'h061b1b77, 32'he0968297, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd3e0c9a0 );

    // atan (-78)
    CMD_CORDIC(32'h06a7366b, 32'he0b303ce, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd46fc3d5 );

    // atan (-77)
    CMD_CORDIC(32'h0732cc8d, 32'he0d1f5df, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd4febe0a );

    // atan (-76)
    CMD_CORDIC(32'h07bdd2fc, 32'he0f35661, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd58db83f );

    // atan (-75)
    CMD_CORDIC(32'h08483ee0, 32'he11722b9, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd61cb274 );

    // atan (-74)
    CMD_CORDIC(32'h08d2056e, 32'he13d581d, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd6abaca9 );

    // atan (-73)
    CMD_CORDIC(32'h095b1be7, 32'he165f392, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd73aa6de );

    // atan (-72)
    CMD_CORDIC(32'h09e3779b, 32'he190f1ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd7c9a113 );

    // atan (-71)
    CMD_CORDIC(32'h0a6b0de8, 32'he1be4fd5, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd8589b48 );

    // atan (-70)
    CMD_CORDIC(32'h0af1d43a, 32'he1ee09be, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd8e7957d );

    // atan (-69)
    CMD_CORDIC(32'h0b77c00f, 32'he2201bf2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hd9768fb2 );

    // atan (-68)
    CMD_CORDIC(32'h0bfcc6f7, 32'he2548287, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hda0589e8 );

    // atan (-67)
    CMD_CORDIC(32'h0c80de91, 32'he28b3968, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hda94841d );

    // atan (-66)
    CMD_CORDIC(32'h0d03fc90, 32'he2c43c52, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hdb237e52 );

    // atan (-65)
    CMD_CORDIC(32'h0d8616bb, 32'he2ff86d0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hdbb27887 );

    // atan (-64)
    CMD_CORDIC(32'h0e0722ed, 32'he33d1445, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hdc4172bc );

    // atan (-63)
    CMD_CORDIC(32'h0e871715, 32'he37cdfe3, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hdcd06cf1 );

    // atan (-62)
    CMD_CORDIC(32'h0f05e93a, 32'he3bee4b1, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hdd5f6726 );

    // atan (-61)
    CMD_CORDIC(32'h0f838f76, 32'he4031d89, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hddee615b );

    // atan (-60)
    CMD_CORDIC(32'h10000000, 32'he4498518, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hde7d5b90 );

    // atan (-59)
    CMD_CORDIC(32'h107b3120, 32'he49215e2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hdf0c55c5 );

    // atan (-58)
    CMD_CORDIC(32'h10f5193e, 32'he4dcca3e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hdf9b4ffa );

    // atan (-57)
    CMD_CORDIC(32'h116daed7, 32'he5299c58, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he02a4a2f );

    // atan (-56)
    CMD_CORDIC(32'h11e4e884, 32'he5788633, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he0b94464 );

    // atan (-55)
    CMD_CORDIC(32'h125abcf8, 32'he5c981a7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he1483e9a );

    // atan (-54)
    CMD_CORDIC(32'h12cf2304, 32'he61c8865, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he1d738cf );

    // atan (-53)
    CMD_CORDIC(32'h13421194, 32'he67193f2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he2663304 );

    // atan (-52)
    CMD_CORDIC(32'h13b37fb1, 32'he6c89dad, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he2f52d39 );

    // atan (-51)
    CMD_CORDIC(32'h14236484, 32'he7219ecb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he384276e );

    // atan (-50)
    CMD_CORDIC(32'h1491b752, 32'he77c905e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he41321a3 );

    // atan (-49)
    CMD_CORDIC(32'h14fe6f81, 32'he7d96b4c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he4a21bd8 );

    // atan (-48)
    CMD_CORDIC(32'h15698496, 32'he8382858, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he531160d );

    // atan (-47)
    CMD_CORDIC(32'h15d2ee39, 32'he898c020, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he5c01042 );

    // atan (-46)
    CMD_CORDIC(32'h163aa430, 32'he8fb2b1a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he64f0a77 );

    // atan (-45)
    CMD_CORDIC(32'h16a09e66, 32'he95f619a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he6de04ac );

    // atan (-44)
    CMD_CORDIC(32'h1704d4e6, 32'he9c55bd0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he76cfee1 );

    // atan (-43)
    CMD_CORDIC(32'h17673fe0, 32'hea2d11c7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he7fbf916 );

    // atan (-42)
    CMD_CORDIC(32'h17c7d7a8, 32'hea967b6a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he88af34b );

    // atan (-41)
    CMD_CORDIC(32'h182694b4, 32'heb01907f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he919ed81 );

    // atan (-40)
    CMD_CORDIC(32'h18836fa2, 32'heb6e48ae, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'he9a8e7b6 );

    // atan (-39)
    CMD_CORDIC(32'h18de6135, 32'hebdc9b7c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hea37e1eb );

    // atan (-38)
    CMD_CORDIC(32'h19376253, 32'hec4c804f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'heac6dc20 );

    // atan (-37)
    CMD_CORDIC(32'h198e6c0e, 32'hecbdee6c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'heb55d655 );

    // atan (-36)
    CMD_CORDIC(32'h19e3779b, 32'hed30dcfc, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hebe4d08a );

    // atan (-35)
    CMD_CORDIC(32'h1a367e59, 32'heda54308, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hec73cabf );

    // atan (-34)
    CMD_CORDIC(32'h1a8779cd, 32'hee1b177c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hed02c4f4 );

    // atan (-33)
    CMD_CORDIC(32'h1ad663a8, 32'hee925129, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hed91bf29 );

    // atan (-32)
    CMD_CORDIC(32'h1b2335c2, 32'hef0ae6c2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hee20b95e );

    // atan (-31)
    CMD_CORDIC(32'h1b6dea1e, 32'hef84cee0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'heeafb393 );

    // atan (-30)
    CMD_CORDIC(32'h1bb67ae8, 32'hf0000001, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hef3eadc8 );

    // atan (-29)
    CMD_CORDIC(32'h1bfce277, 32'hf07c708a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hefcda7fd );

    // atan (-28)
    CMD_CORDIC(32'h1c411b4f, 32'hf0fa16c6, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf05ca232 );

    // atan (-27)
    CMD_CORDIC(32'h1c83201d, 32'hf178e8eb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf0eb9c68 );

    // atan (-26)
    CMD_CORDIC(32'h1cc2ebbb, 32'hf1f8dd13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf17a969d );

    // atan (-25)
    CMD_CORDIC(32'h1d007930, 32'hf279e945, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf20990d2 );

    // atan (-24)
    CMD_CORDIC(32'h1d3bc3ae, 32'hf2fc0370, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf2988b07 );

    // atan (-23)
    CMD_CORDIC(32'h1d74c698, 32'hf37f216f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf327853c );

    // atan (-22)
    CMD_CORDIC(32'h1dab7d79, 32'hf4033909, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf3b67f71 );

    // atan (-21)
    CMD_CORDIC(32'h1ddfe40e, 32'hf4883ff1, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf44579a6 );

    // atan (-20)
    CMD_CORDIC(32'h1e11f642, 32'hf50e2bc6, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf4d473db );

    // atan (-19)
    CMD_CORDIC(32'h1e41b02b, 32'hf594f218, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf5636e10 );

    // atan (-18)
    CMD_CORDIC(32'h1e6f0e13, 32'hf61c8865, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf5f26845 );

    // atan (-17)
    CMD_CORDIC(32'h1e9a0c6e, 32'hf6a4e419, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf681627a );

    // atan (-16)
    CMD_CORDIC(32'h1ec2a7e3, 32'hf72dfa92, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf7105caf );

    // atan (-15)
    CMD_CORDIC(32'h1ee8dd47, 32'hf7b7c120, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf79f56e4 );

    // atan (-14)
    CMD_CORDIC(32'h1f0ca99f, 32'hf8422d04, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf82e5119 );

    // atan (-13)
    CMD_CORDIC(32'h1f2e0a21, 32'hf8cd3373, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf8bd4b4f );

    // atan (-12)
    CMD_CORDIC(32'h1f4cfc32, 32'hf958c995, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf94c4584 );

    // atan (-11)
    CMD_CORDIC(32'h1f697d69, 32'hf9e4e489, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hf9db3fb9 );

    // atan (-10)
    CMD_CORDIC(32'h1f838b8c, 32'hfa717961, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfa6a39ee );

    // atan (-9)
    CMD_CORDIC(32'h1f9b2494, 32'hfafe7d27, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfaf93423 );

    // atan (-8)
    CMD_CORDIC(32'h1fb046a9, 32'hfb8be4db, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfb882e58 );

    // atan (-7)
    CMD_CORDIC(32'h1fc2f025, 32'hfc19a577, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfc17288d );

    // atan (-6)
    CMD_CORDIC(32'h1fd31f94, 32'hfca7b3ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfca622c2 );

    // atan (-5)
    CMD_CORDIC(32'h1fe0d3b4, 32'hfd360529, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfd351cf7 );

    // atan (-4)
    CMD_CORDIC(32'h1fec0b71, 32'hfdc48e13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfdc4172c );

    // atan (-3)
    CMD_CORDIC(32'h1ff4c5ed, 32'hfe53438c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfe531161 );

    // atan (-2)
    CMD_CORDIC(32'h1ffb0278, 32'hfee21a74, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hfee20b96 );

    // atan (-1)
    CMD_CORDIC(32'h1ffec097, 32'hff7107a7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'hff7105cb );

    // atan (0)
    CMD_CORDIC(32'h20000000, 32'h00000000, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h00000000 );

    // atan (1)
    CMD_CORDIC(32'h1ffec097, 32'h008ef859, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h008efa35 );

    // atan (2)
    CMD_CORDIC(32'h1ffb0278, 32'h011de58c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h011df46a );

    // atan (3)
    CMD_CORDIC(32'h1ff4c5ed, 32'h01acbc74, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h01acee9f );

    // atan (4)
    CMD_CORDIC(32'h1fec0b71, 32'h023b71ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h023be8d4 );

    // atan (5)
    CMD_CORDIC(32'h1fe0d3b4, 32'h02c9fad7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h02cae309 );

    // atan (6)
    CMD_CORDIC(32'h1fd31f94, 32'h03584c13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0359dd3e );

    // atan (7)
    CMD_CORDIC(32'h1fc2f025, 32'h03e65a89, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h03e8d773 );

    // atan (8)
    CMD_CORDIC(32'h1fb046a9, 32'h04741b25, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0477d1a8 );

    // atan (9)
    CMD_CORDIC(32'h1f9b2494, 32'h050182d9, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0506cbdd );

    // atan (10)
    CMD_CORDIC(32'h1f838b8c, 32'h058e869f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0595c612 );

    // atan (11)
    CMD_CORDIC(32'h1f697d69, 32'h061b1b77, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0624c047 );

    // atan (12)
    CMD_CORDIC(32'h1f4cfc32, 32'h06a7366b, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h06b3ba7c );

    // atan (13)
    CMD_CORDIC(32'h1f2e0a21, 32'h0732cc8d, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0742b4b1 );

    // atan (14)
    CMD_CORDIC(32'h1f0ca99f, 32'h07bdd2fc, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h07d1aee7 );

    // atan (15)
    CMD_CORDIC(32'h1ee8dd47, 32'h08483ee0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0860a91c );

    // atan (16)
    CMD_CORDIC(32'h1ec2a7e3, 32'h08d2056e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h08efa351 );

    // atan (17)
    CMD_CORDIC(32'h1e9a0c6e, 32'h095b1be7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h097e9d86 );

    // atan (18)
    CMD_CORDIC(32'h1e6f0e13, 32'h09e3779b, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0a0d97bb );

    // atan (19)
    CMD_CORDIC(32'h1e41b02b, 32'h0a6b0de8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0a9c91f0 );

    // atan (20)
    CMD_CORDIC(32'h1e11f642, 32'h0af1d43a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0b2b8c25 );

    // atan (21)
    CMD_CORDIC(32'h1ddfe40e, 32'h0b77c00f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0bba865a );

    // atan (22)
    CMD_CORDIC(32'h1dab7d79, 32'h0bfcc6f7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0c49808f );

    // atan (23)
    CMD_CORDIC(32'h1d74c698, 32'h0c80de91, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0cd87ac4 );

    // atan (24)
    CMD_CORDIC(32'h1d3bc3ae, 32'h0d03fc90, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0d6774f9 );

    // atan (25)
    CMD_CORDIC(32'h1d007930, 32'h0d8616bb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0df66f2e );

    // atan (26)
    CMD_CORDIC(32'h1cc2ebbb, 32'h0e0722ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0e856963 );

    // atan (27)
    CMD_CORDIC(32'h1c83201d, 32'h0e871715, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0f146398 );

    // atan (28)
    CMD_CORDIC(32'h1c411b4f, 32'h0f05e93a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h0fa35dce );

    // atan (29)
    CMD_CORDIC(32'h1bfce277, 32'h0f838f76, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h10325803 );

    // atan (30)
    CMD_CORDIC(32'h1bb67ae8, 32'h0fffffff, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h10c15238 );

    // atan (31)
    CMD_CORDIC(32'h1b6dea1e, 32'h107b3120, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h11504c6d );

    // atan (32)
    CMD_CORDIC(32'h1b2335c2, 32'h10f5193e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h11df46a2 );

    // atan (33)
    CMD_CORDIC(32'h1ad663a8, 32'h116daed7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h126e40d7 );

    // atan (34)
    CMD_CORDIC(32'h1a8779cd, 32'h11e4e884, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h12fd3b0c );

    // atan (35)
    CMD_CORDIC(32'h1a367e59, 32'h125abcf8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h138c3541 );

    // atan (36)
    CMD_CORDIC(32'h19e3779b, 32'h12cf2304, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h141b2f76 );

    // atan (37)
    CMD_CORDIC(32'h198e6c0e, 32'h13421194, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h14aa29ab );

    // atan (38)
    CMD_CORDIC(32'h19376253, 32'h13b37fb1, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h153923e0 );

    // atan (39)
    CMD_CORDIC(32'h18de6135, 32'h14236484, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h15c81e15 );

    // atan (40)
    CMD_CORDIC(32'h18836fa2, 32'h1491b752, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1657184a );

    // atan (41)
    CMD_CORDIC(32'h182694b4, 32'h14fe6f81, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h16e6127f );

    // atan (42)
    CMD_CORDIC(32'h17c7d7a8, 32'h15698496, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h17750cb5 );

    // atan (43)
    CMD_CORDIC(32'h17673fe0, 32'h15d2ee39, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h180406ea );

    // atan (44)
    CMD_CORDIC(32'h1704d4e6, 32'h163aa430, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1893011f );

    // atan (45)
    CMD_CORDIC(32'h16a09e66, 32'h16a09e66, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1921fb54 );

    // atan (46)
    CMD_CORDIC(32'h163aa430, 32'h1704d4e6, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h19b0f589 );

    // atan (47)
    CMD_CORDIC(32'h15d2ee39, 32'h17673fe0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1a3fefbe );

    // atan (48)
    CMD_CORDIC(32'h15698496, 32'h17c7d7a8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1acee9f3 );

    // atan (49)
    CMD_CORDIC(32'h14fe6f81, 32'h182694b4, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1b5de428 );

    // atan (50)
    CMD_CORDIC(32'h1491b752, 32'h18836fa2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1becde5d );

    // atan (51)
    CMD_CORDIC(32'h14236484, 32'h18de6135, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1c7bd892 );

    // atan (52)
    CMD_CORDIC(32'h13b37fb1, 32'h19376253, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1d0ad2c7 );

    // atan (53)
    CMD_CORDIC(32'h13421194, 32'h198e6c0e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1d99ccfc );

    // atan (54)
    CMD_CORDIC(32'h12cf2304, 32'h19e3779b, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1e28c731 );

    // atan (55)
    CMD_CORDIC(32'h125abcf8, 32'h1a367e59, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1eb7c166 );

    // atan (56)
    CMD_CORDIC(32'h11e4e884, 32'h1a8779cd, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1f46bb9c );

    // atan (57)
    CMD_CORDIC(32'h116daed7, 32'h1ad663a8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h1fd5b5d1 );

    // atan (58)
    CMD_CORDIC(32'h10f5193e, 32'h1b2335c2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2064b006 );

    // atan (59)
    CMD_CORDIC(32'h107b3120, 32'h1b6dea1e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h20f3aa3b );

    // atan (60)
    CMD_CORDIC(32'h10000000, 32'h1bb67ae8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2182a470 );

    // atan (61)
    CMD_CORDIC(32'h0f838f76, 32'h1bfce277, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h22119ea5 );

    // atan (62)
    CMD_CORDIC(32'h0f05e93a, 32'h1c411b4f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h22a098da );

    // atan (63)
    CMD_CORDIC(32'h0e871715, 32'h1c83201d, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h232f930f );

    // atan (64)
    CMD_CORDIC(32'h0e0722ed, 32'h1cc2ebbb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h23be8d44 );

    // atan (65)
    CMD_CORDIC(32'h0d8616bb, 32'h1d007930, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h244d8779 );

    // atan (66)
    CMD_CORDIC(32'h0d03fc90, 32'h1d3bc3ae, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h24dc81ae );

    // atan (67)
    CMD_CORDIC(32'h0c80de91, 32'h1d74c698, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h256b7be3 );

    // atan (68)
    CMD_CORDIC(32'h0bfcc6f7, 32'h1dab7d79, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h25fa7618 );

    // atan (69)
    CMD_CORDIC(32'h0b77c00f, 32'h1ddfe40e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2689704e );

    // atan (70)
    CMD_CORDIC(32'h0af1d43a, 32'h1e11f642, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h27186a83 );

    // atan (71)
    CMD_CORDIC(32'h0a6b0de8, 32'h1e41b02b, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h27a764b8 );

    // atan (72)
    CMD_CORDIC(32'h09e3779b, 32'h1e6f0e13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h28365eed );

    // atan (73)
    CMD_CORDIC(32'h095b1be7, 32'h1e9a0c6e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h28c55922 );

    // atan (74)
    CMD_CORDIC(32'h08d2056e, 32'h1ec2a7e3, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h29545357 );

    // atan (75)
    CMD_CORDIC(32'h08483ee0, 32'h1ee8dd47, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h29e34d8c );

    // atan (76)
    CMD_CORDIC(32'h07bdd2fc, 32'h1f0ca99f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2a7247c1 );

    // atan (77)
    CMD_CORDIC(32'h0732cc8d, 32'h1f2e0a21, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2b0141f6 );

    // atan (78)
    CMD_CORDIC(32'h06a7366b, 32'h1f4cfc32, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2b903c2b );

    // atan (79)
    CMD_CORDIC(32'h061b1b77, 32'h1f697d69, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2c1f3660 );

    // atan (80)
    CMD_CORDIC(32'h058e869f, 32'h1f838b8c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2cae3095 );

    // atan (81)
    CMD_CORDIC(32'h050182d9, 32'h1f9b2494, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2d3d2aca );

    // atan (82)
    CMD_CORDIC(32'h04741b25, 32'h1fb046a9, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2dcc24ff );

    // atan (83)
    CMD_CORDIC(32'h03e65a89, 32'h1fc2f025, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2e5b1f35 );

    // atan (84)
    CMD_CORDIC(32'h03584c13, 32'h1fd31f94, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2eea196a );

    // atan (85)
    CMD_CORDIC(32'h02c9fad7, 32'h1fe0d3b4, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h2f79139f );

    // atan (86)
    CMD_CORDIC(32'h023b71ed, 32'h1fec0b71, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h30080dd4 );

    // atan (87)
    CMD_CORDIC(32'h01acbc74, 32'h1ff4c5ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h30970809 );

    // atan (88)
    CMD_CORDIC(32'h011de58c, 32'h1ffb0278, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3126023e );

    // atan (89)
    CMD_CORDIC(32'h008ef859, 32'h1ffec097, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h31b4fc73 );

    // atan (90)
    CMD_CORDIC(32'h00000000, 32'h20000000, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3243f6a8 );

    // atan (91)
    CMD_CORDIC(32'hff7107a7, 32'h1ffec097, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h32d2f0dd );

    // atan (92)
    CMD_CORDIC(32'hfee21a74, 32'h1ffb0278, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3361eb12 );

    // atan (93)
    CMD_CORDIC(32'hfe53438c, 32'h1ff4c5ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h33f0e547 );

    // atan (94)
    CMD_CORDIC(32'hfdc48e13, 32'h1fec0b71, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h347fdf7c );

    // atan (95)
    CMD_CORDIC(32'hfd360529, 32'h1fe0d3b4, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h350ed9b1 );

    // atan (96)
    CMD_CORDIC(32'hfca7b3ed, 32'h1fd31f94, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h359dd3e6 );

    // atan (97)
    CMD_CORDIC(32'hfc19a577, 32'h1fc2f025, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h362cce1c );

    // atan (98)
    CMD_CORDIC(32'hfb8be4db, 32'h1fb046a9, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h36bbc851 );

    // atan (99)
    CMD_CORDIC(32'hfafe7d27, 32'h1f9b2494, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h374ac286 );

    // atan (100)
    CMD_CORDIC(32'hfa717961, 32'h1f838b8c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h37d9bcbb );

    // atan (101)
    CMD_CORDIC(32'hf9e4e489, 32'h1f697d69, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3868b6f0 );

    // atan (102)
    CMD_CORDIC(32'hf958c995, 32'h1f4cfc32, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h38f7b125 );

    // atan (103)
    CMD_CORDIC(32'hf8cd3373, 32'h1f2e0a21, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3986ab5a );

    // atan (104)
    CMD_CORDIC(32'hf8422d04, 32'h1f0ca99f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3a15a58f );

    // atan (105)
    CMD_CORDIC(32'hf7b7c120, 32'h1ee8dd47, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3aa49fc4 );

    // atan (106)
    CMD_CORDIC(32'hf72dfa92, 32'h1ec2a7e3, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3b3399f9 );

    // atan (107)
    CMD_CORDIC(32'hf6a4e419, 32'h1e9a0c6e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3bc2942e );

    // atan (108)
    CMD_CORDIC(32'hf61c8865, 32'h1e6f0e13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3c518e63 );

    // atan (109)
    CMD_CORDIC(32'hf594f218, 32'h1e41b02b, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3ce08898 );

    // atan (110)
    CMD_CORDIC(32'hf50e2bc6, 32'h1e11f642, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3d6f82cd );

    // atan (111)
    CMD_CORDIC(32'hf4883ff1, 32'h1ddfe40e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3dfe7d03 );

    // atan (112)
    CMD_CORDIC(32'hf4033909, 32'h1dab7d79, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3e8d7738 );

    // atan (113)
    CMD_CORDIC(32'hf37f216f, 32'h1d74c698, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3f1c716d );

    // atan (114)
    CMD_CORDIC(32'hf2fc0370, 32'h1d3bc3ae, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h3fab6ba2 );

    // atan (115)
    CMD_CORDIC(32'hf279e945, 32'h1d007930, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h403a65d7 );

    // atan (116)
    CMD_CORDIC(32'hf1f8dd13, 32'h1cc2ebbb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h40c9600c );

    // atan (117)
    CMD_CORDIC(32'hf178e8eb, 32'h1c83201d, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h41585a41 );

    // atan (118)
    CMD_CORDIC(32'hf0fa16c6, 32'h1c411b4f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h41e75476 );

    // atan (119)
    CMD_CORDIC(32'hf07c708a, 32'h1bfce277, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h42764eab );

    // atan (120)
    CMD_CORDIC(32'hf0000001, 32'h1bb67ae8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h430548e0 );

    // atan (121)
    CMD_CORDIC(32'hef84cee0, 32'h1b6dea1e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h43944315 );

    // atan (122)
    CMD_CORDIC(32'hef0ae6c2, 32'h1b2335c2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h44233d4a );

    // atan (123)
    CMD_CORDIC(32'hee925129, 32'h1ad663a8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h44b2377f );

    // atan (124)
    CMD_CORDIC(32'hee1b177c, 32'h1a8779cd, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h454131b5 );

    // atan (125)
    CMD_CORDIC(32'heda54308, 32'h1a367e59, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h45d02bea );

    // atan (126)
    CMD_CORDIC(32'hed30dcfc, 32'h19e3779b, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h465f261f );

    // atan (127)
    CMD_CORDIC(32'hecbdee6c, 32'h198e6c0e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h46ee2054 );

    // atan (128)
    CMD_CORDIC(32'hec4c804f, 32'h19376253, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h477d1a89 );

    // atan (129)
    CMD_CORDIC(32'hebdc9b7c, 32'h18de6135, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h480c14be );

    // atan (130)
    CMD_CORDIC(32'heb6e48ae, 32'h18836fa2, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h489b0ef3 );

    // atan (131)
    CMD_CORDIC(32'heb01907f, 32'h182694b4, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h492a0928 );

    // atan (132)
    CMD_CORDIC(32'hea967b6a, 32'h17c7d7a8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h49b9035d );

    // atan (133)
    CMD_CORDIC(32'hea2d11c7, 32'h17673fe0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4a47fd92 );

    // atan (134)
    CMD_CORDIC(32'he9c55bd0, 32'h1704d4e6, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4ad6f7c7 );

    // atan (135)
    CMD_CORDIC(32'he95f619a, 32'h16a09e66, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4b65f1fc );

    // atan (136)
    CMD_CORDIC(32'he8fb2b1a, 32'h163aa430, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4bf4ec31 );

    // atan (137)
    CMD_CORDIC(32'he898c020, 32'h15d2ee39, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4c83e666 );

    // atan (138)
    CMD_CORDIC(32'he8382858, 32'h15698496, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4d12e09c );

    // atan (139)
    CMD_CORDIC(32'he7d96b4c, 32'h14fe6f81, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4da1dad1 );

    // atan (140)
    CMD_CORDIC(32'he77c905e, 32'h1491b752, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4e30d506 );

    // atan (141)
    CMD_CORDIC(32'he7219ecb, 32'h14236484, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4ebfcf3b );

    // atan (142)
    CMD_CORDIC(32'he6c89dad, 32'h13b37fb1, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4f4ec970 );

    // atan (143)
    CMD_CORDIC(32'he67193f2, 32'h13421194, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h4fddc3a5 );

    // atan (144)
    CMD_CORDIC(32'he61c8865, 32'h12cf2304, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h506cbdda );

    // atan (145)
    CMD_CORDIC(32'he5c981a7, 32'h125abcf8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h50fbb80f );

    // atan (146)
    CMD_CORDIC(32'he5788633, 32'h11e4e884, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h518ab244 );

    // atan (147)
    CMD_CORDIC(32'he5299c58, 32'h116daed7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5219ac79 );

    // atan (148)
    CMD_CORDIC(32'he4dcca3e, 32'h10f5193e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h52a8a6ae );

    // atan (149)
    CMD_CORDIC(32'he49215e2, 32'h107b3120, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5337a0e3 );

    // atan (150)
    CMD_CORDIC(32'he4498518, 32'h0fffffff, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h53c69b18 );

    // atan (151)
    CMD_CORDIC(32'he4031d89, 32'h0f838f76, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5455954d );

    // atan (152)
    CMD_CORDIC(32'he3bee4b1, 32'h0f05e93a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h54e48f83 );

    // atan (153)
    CMD_CORDIC(32'he37cdfe3, 32'h0e871715, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h557389b8 );

    // atan (154)
    CMD_CORDIC(32'he33d1445, 32'h0e0722ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h560283ed );

    // atan (155)
    CMD_CORDIC(32'he2ff86d0, 32'h0d8616bb, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h56917e22 );

    // atan (156)
    CMD_CORDIC(32'he2c43c52, 32'h0d03fc90, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h57207857 );

    // atan (157)
    CMD_CORDIC(32'he28b3968, 32'h0c80de91, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h57af728c );

    // atan (158)
    CMD_CORDIC(32'he2548287, 32'h0bfcc6f7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h583e6cc1 );

    // atan (159)
    CMD_CORDIC(32'he2201bf2, 32'h0b77c00f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h58cd66f6 );

    // atan (160)
    CMD_CORDIC(32'he1ee09be, 32'h0af1d43a, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h595c612b );

    // atan (161)
    CMD_CORDIC(32'he1be4fd5, 32'h0a6b0de8, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h59eb5b60 );

    // atan (162)
    CMD_CORDIC(32'he190f1ed, 32'h09e3779b, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5a7a5595 );

    // atan (163)
    CMD_CORDIC(32'he165f392, 32'h095b1be7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5b094fca );

    // atan (164)
    CMD_CORDIC(32'he13d581d, 32'h08d2056e, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5b9849ff );

    // atan (165)
    CMD_CORDIC(32'he11722b9, 32'h08483ee0, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5c274434 );

    // atan (166)
    CMD_CORDIC(32'he0f35661, 32'h07bdd2fc, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5cb63e6a );

    // atan (167)
    CMD_CORDIC(32'he0d1f5df, 32'h0732cc8d, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5d45389f );

    // atan (168)
    CMD_CORDIC(32'he0b303ce, 32'h06a7366b, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5dd432d4 );

    // atan (169)
    CMD_CORDIC(32'he0968297, 32'h061b1b77, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5e632d09 );

    // atan (170)
    CMD_CORDIC(32'he07c7474, 32'h058e869f, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5ef2273e );

    // atan (171)
    CMD_CORDIC(32'he064db6c, 32'h050182d9, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h5f812173 );

    // atan (172)
    CMD_CORDIC(32'he04fb957, 32'h04741b25, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h60101ba8 );

    // atan (173)
    CMD_CORDIC(32'he03d0fdb, 32'h03e65a89, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h609f15dd );

    // atan (174)
    CMD_CORDIC(32'he02ce06c, 32'h03584c13, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h612e1012 );

    // atan (175)
    CMD_CORDIC(32'he01f2c4c, 32'h02c9fad7, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h61bd0a47 );

    // atan (176)
    CMD_CORDIC(32'he013f48f, 32'h023b71ed, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h624c047c );

    // atan (177)
    CMD_CORDIC(32'he00b3a13, 32'h01acbc74, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h62dafeb1 );

    // atan (178)
    CMD_CORDIC(32'he004fd88, 32'h011de58c, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h6369f8e6 );

    // atan (179)
    CMD_CORDIC(32'he0013f69, 32'h008ef859, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h63f8f31b );

    // atan (180)
    CMD_CORDIC(32'he0000000, 32'h00000000, 0,  `CMD_ATAN, 
              32'h0, 32'h0, 32'h6487ed51 );



//    $shm_close();
    $finish;
end



initial begin
    forever #5 PCLK=~PCLK;
end


//====================================================
// design top
//====================================================

// serial output from SSP is looped back to the serial input.
Cd_top cd_top(  .PCLK(PCLK),
		.PRESETn(PRESETn),
		.PSEL(PSEL),
		.PADDR(PADDR),
		.PENABLE(PENABLE),
		.PWRITE(PWRITE),
		.PWDATA(PWDATA),
		.PRDATA(PRDATA),
		.INT(INT));

//====================================================
// test tasks
//====================================================


task APB_write;
input [31:0] paddr;
input [31:0] pdata;
begin
    PSEL <= 1;
    PADDR <= paddr;
    PWDATA <= pdata;
    PENABLE <= 0;
    PWRITE <= 1;

    @(posedge PCLK);
    PENABLE <= 1;
    @(posedge PCLK);
    PENABLE <= 0;
    PSEL <= 0;
   
end
endtask



task APB_read;
input [31:0] paddr;
begin
    PSEL <=1;
    PADDR <= paddr;
    PENABLE <= 0;
    PWRITE <= 0;

    @(posedge PCLK);
    PENABLE <= 1;

    @(posedge PCLK);
    PENABLE <= 0;
    PSEL <= 0;
end
endtask


reg [31:0] tmp1,tmp2;
reg [31:0] data_read;
reg [31:0] error; 

task APB_verify;
input [31:0] paddr;
input [31:0] chk_data;
begin
    PSEL <=1;
    PADDR <= paddr;
    PENABLE <= 0;
    PWRITE <= 0;

    @(posedge PCLK);
    PENABLE <= 1;

    @(posedge PCLK);
    tmp1=(chk_data[31]==1'b0)? chk_data[31:0]:(~chk_data[31:0]+32'h1);
    tmp2=(PRDATA[31]==1'b0)? PRDATA[31:0]:(~PRDATA[31:0]+32'h1);
    error=(tmp1>tmp2)?(tmp1-tmp2):(tmp2-tmp1);
    if(chk_data==`DONTCARE)error=0;
    data_read=PRDATA;

    PENABLE <= 0;
    PSEL <= 0;
end
endtask



task CMD_CORDIC;
input [31:0] x_in,y_in,z_in,cmd;
input [31:0] x_out,y_out,z_out;
begin

    $display("# CMD:X_IN=%h Y_IN=%h Z_IN=%h CMD=%h",x_in,y_in,z_in,cmd);

    //rotate(60)    
    APB_write(`X_IN,x_in);
    APB_write(`Y_IN,y_in);
    APB_write(`Z_IN,z_in);
    APB_write(`CTRL,cmd);

    while(INT==1'b0)begin
	@(posedge PCLK);
    end

//    repeat(31) @(posedge PCLK);
	
    
    APB_write(`CTRL,`CMD_CLEARPEND);	 
    APB_verify(`X_OUT,x_out);

    if(error>32'hf)
	$display(" ERROR: X_OUT=%h,X_OUT_bus=%h err=%h",x_out,data_read,error);
    APB_verify(`Y_OUT,y_out);
    if(error>32'hf)
	$display(" ERROR: Y_OUT=%h,Y_OUT_bus=%h err=%h",y_out,data_read,error);
    APB_verify(`Z_OUT,z_out);
    if(error>32'hf)
	$display(" ERROR: Z_OUT=%h,Z_OUT_bus=%h err=%h",z_out,data_read,error);
   
end
endtask



//initial #5000 $finish;

   
// Dump all waveforms to cd_test.dump
initial

begin
//  $dumpfile ("cd_test.dump");
//  $dumpvars (0, cd_test);

//    $shm_open("waves.shm");  // Open database named "..."
//    $shm_probe(cd_test,"AS");// Record tb scope and all sub hierarchy
    //$shm_probe(cd_test,"A");// Record only those signals at tb.dut scope
    //$shm_close();  
end 
endmodule




module timeunit;
initial $timeformat(-9,1," ns",9);
endmodule
