`timescale 1ns/10ps

module cd_test;

reg PCLK;
reg PRESETn;
reg PSEL;
reg PENABLE;
reg [4:0] PADDR;
reg PWRITE;
reg [31:0] PWDATA;
wire [31:0] PRDATA;
wire INT;


// cordic address map
`define CTRL 		5'h0
`define X_IN 		5'h4
`define Y_IN  		5'h8
`define Z_IN		5'hc
`define X_OUT		5'h10
`define Y_OUT		5'h14
`define Z_OUT		5'h18
`define STATUS		5'h1c

`define RAD_60		32'h2182a470
`define RAD_120		32'h430548e0
`define RAD_N60		(~`RAD_60+32'h1)
`define RAD_N120	(~`RAD_120+32'h1)
`define RAD_45		32'h1921fb54
`define RAD_N45		(~`RAD_45+32'h1)
`define RAD_135		32'h4b65f1fc
`define RAD_N135	(~`RAD_135+32'h1)
	
`define ROOT_P5		32'h16a09e66
`define NROOT_P5	(~`ROOT_P5+32'h1)
`define COS_60		32'h10000000
`define NCOS_60		(~`COS_60+32'h1)
`define SIN_60		32'h1bb67ae8
`define NSIN_60		(~`SIN_60+32'h1)
`define ONE_BY_R	32'h136e9db5
`define R		32'h34b24291

`define CMD_SINCOS	32'h00000023
`define CMD_ROTATE	32'h00000025
`define CMD_ATAN	32'h00000027
`define CMD_MAG_ATAN	32'h00000029
`define CMD_CLEARPEND   32'h00000040
`define DONTCARE	32'h7fffffff

initial begin
    PCLK=0;
    PRESETn=0;
    @(posedge PCLK);
    @(posedge PCLK);
    PRESETn=1;

/*
    //cos/sin(60)    
    APB_write(`X_IN,32'h0);
    APB_write(`Y_IN,32'h0);
    APB_write(`Z_IN,`RAD_60);
    APB_write(`CTRL,`CMD_SINCOS);

    repeat(31) @(posedge PCLK);
    
    APB_write(`CTRL,`CMD_CLEARPEND);	 
    APB_read(`X_OUT);
    APB_read(`Y_OUT);
    APB_read(`Z_OUT);
*/
    //cos,sin(60)
    CMD_CORDIC(32'h0,32'h0,`RAD_60,`CMD_SINCOS,
	       32'h10000000,32'h1bb67ae8,32'h0);
    //cos,sin(-60)
    CMD_CORDIC(32'h0,32'h0,`RAD_N60,`CMD_SINCOS,
	       32'h10000000,32'he4498518,32'h0);
    //cos,sin(120)
    CMD_CORDIC(32'h0,32'h0,`RAD_120,`CMD_SINCOS,
	       32'hf0000001,32'h1bb67ae8,32'h0);
    //cos,sin(-120)
    CMD_CORDIC(32'h0,32'h0,`RAD_N120,`CMD_SINCOS,
	       32'h10000000,32'he4498518,32'h0);


    //rotate(60)
    CMD_CORDIC(`ONE_BY_R,32'h0,`RAD_60,`CMD_ROTATE,
	       32'h10000000,32'h1bb67ae8,32'h0);
    //rotate(-60)
    CMD_CORDIC(`ONE_BY_R,32'h0,`RAD_N60,`CMD_ROTATE,
	       32'h10000000,32'he4498518,32'h0);
    //rotate(120)
    CMD_CORDIC(`ONE_BY_R,32'h0,`RAD_120,`CMD_ROTATE,
	       32'hf0000001,32'h1bb67ae8,32'h0);
    //rotate(-120)
    CMD_CORDIC(`ONE_BY_R,32'h0,`RAD_N120,`CMD_ROTATE,
	       32'h10000000,32'he4498518,32'h0);



    //atan(45) & magnitude
    CMD_CORDIC(`ROOT_P5,`ROOT_P5,0,`CMD_MAG_ATAN,
	       `R,32'h0,`RAD_45);
    //atan(-45) & magnitude
    CMD_CORDIC(`ROOT_P5,`NROOT_P5,0,`CMD_MAG_ATAN,
	       `R,32'h0,`RAD_N45);
    //atan(135) & magnitude
    CMD_CORDIC(`NROOT_P5,`ROOT_P5,0,`CMD_MAG_ATAN,
	       `R,32'h0,`RAD_135);
    //atan(-135) & magnitude
    CMD_CORDIC(`NROOT_P5,`NROOT_P5,0,`CMD_MAG_ATAN,
	       `R,32'h0,`RAD_N135);


    //atan(45)
    CMD_CORDIC(`ROOT_P5,`ROOT_P5,0,`CMD_ATAN,
	       32'h0,32'h0,`RAD_45);
    //atan(-45)
    CMD_CORDIC(`ROOT_P5,`NROOT_P5,0,`CMD_ATAN,
	       32'h0,32'h0,`RAD_N45);
    //atan(135)
    CMD_CORDIC(`NROOT_P5,`ROOT_P5,0,`CMD_ATAN,
	       32'h0,32'h0,`RAD_135);
    //atan(-135)
    CMD_CORDIC(`NROOT_P5,`NROOT_P5,0,`CMD_ATAN,
	       32'h0,32'h0,`RAD_N135);

    //atan(60)
    CMD_CORDIC(`COS_60,`SIN_60,0,`CMD_ATAN,
	       32'h0,32'h0,`RAD_60);
    //atan(-60)
    CMD_CORDIC(`COS_60,`NSIN_60,0,`CMD_ATAN,
	       32'h0,32'h0,`RAD_N60);
    //atan(120)
    CMD_CORDIC(`NCOS_60,`SIN_60,0,`CMD_ATAN,
	       32'h0,32'h0,`RAD_120);
    //atan(-120)
    CMD_CORDIC(`NCOS_60,`NSIN_60,0,`CMD_ATAN,
	       32'h0,32'h0,`RAD_N120);



    $shm_close();
    $finish;
end



initial begin
    forever #5 PCLK=~PCLK;
end


//====================================================
// design top
//====================================================

// serial output from SSP is looped back to the serial input.
Cd_top cd_top(  .PCLK(PCLK),
		.PRESETn(PRESETn),
		.PSEL(PSEL),
		.PADDR(PADDR),
		.PENABLE(PENABLE),
		.PWRITE(PWRITE),
		.PWDATA(PWDATA),
		.PRDATA(PRDATA),
		.INT(INT));

//====================================================
// test tasks
//====================================================


task APB_write;
input [31:0] paddr;
input [31:0] pdata;
begin
    PSEL <= 1;
    PADDR <= paddr;
    PWDATA <= pdata;
    PENABLE <= 0;
    PWRITE <= 1;

    @(posedge PCLK);
    PENABLE <= 1;
    @(posedge PCLK);
    PENABLE <= 0;
    PSEL <= 0;
   
end
endtask



task APB_read;
input [31:0] paddr;
begin
    PSEL <=1;
    PADDR <= paddr;
    PENABLE <= 0;
    PWRITE <= 0;

    @(posedge PCLK);
    PENABLE <= 1;

    @(posedge PCLK);
    PENABLE <= 0;
    PSEL <= 0;
end
endtask


reg [31:0] tmp1,tmp2;
reg [31:0] data_read;
reg [31:0] error; 

task APB_verify;
input [31:0] paddr;
input [31:0] chk_data;
begin
    PSEL <=1;
    PADDR <= paddr;
    PENABLE <= 0;
    PWRITE <= 0;

    @(posedge PCLK);
    PENABLE <= 1;

    @(posedge PCLK);
    tmp1=(chk_data[31]==1'b0)? chk_data[31:0]:(~chk_data[31:0]+32'h1);
    tmp2=(PRDATA[31]==1'b0)? PRDATA[31:0]:(~PRDATA[31:0]+32'h1);
    error=(tmp1>tmp2)?(tmp1-tmp2):(tmp2-tmp1);
    if(chk_data==`DONTCARE)error=0;
    data_read=PRDATA;

    PENABLE <= 0;
    PSEL <= 0;
end
endtask



task CMD_CORDIC;
input [31:0] x_in,y_in,z_in,cmd;
input [31:0] x_out,y_out,z_out;
begin

    $display("# CMD:X_IN=%h Y_IN=%h Z_IN=%h CMD=%h",x_in,y_in,z_in,cmd);

    //rotate(60)    
    APB_write(`X_IN,x_in);
    APB_write(`Y_IN,y_in);
    APB_write(`Z_IN,z_in);
    APB_write(`CTRL,cmd);

    while(INT==1'b0)begin
	@(posedge PCLK);
    end

//    repeat(31) @(posedge PCLK);
	
    
    APB_write(`CTRL,`CMD_CLEARPEND);	 
    APB_verify(`X_OUT,x_out);

    if(error>32'hf)
	$display(" ERROR: X_OUT=%h,X_OUT_bus=%h err=%h",x_out,data_read,error);
    APB_verify(`Y_OUT,y_out);
    if(error>32'hf)
	$display(" ERROR: Y_OUT=%h,Y_OUT_bus=%h err=%h",y_out,data_read,error);
    APB_verify(`Z_OUT,z_out);
    if(error>32'hf)
	$display(" ERROR: Z_OUT=%h,Z_OUT_bus=%h err=%h",z_out,data_read,error);
   
end
endtask



//initial #5000 $finish;

   
// Dump all waveforms to cd_test.dump
initial

begin
//  $dumpfile ("cd_test.dump");
//  $dumpvars (0, cd_test);

    $shm_open("waves.shm");  // Open database named "..."
    $shm_probe(cd_test,"AS");// Record tb scope and all sub hierarchy
    //$shm_probe(cd_test,"A");// Record only those signals at tb.dut scope
    //$shm_close();  
end 
endmodule




module timeunit;
initial $timeformat(-9,1," ns",9);
endmodule